function [residual, g1, g2, g3] = cycle_irf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(82, 1);
T53 = params(2)*exp(y(105))/exp(y(52));
T90 = (1-params(6))/params(6)*exp(y(30))*1/(1-exp(y(70)));
T117 = exp(y(58))*exp(y(24))^params(20)*exp(y(1))^params(10);
T121 = exp(y(14))^(1-params(10));
T134 = exp(y(42));
T163 = exp(y(48))/exp(y(20));
T183 = exp(y(105))/exp(y(52));
T210 = exp(.5*(params(14)-exp(y(40)))/(exp(y(40))*params(14)*params(15)));
T230 = 1/T134*exp(y(33))/exp(y(40));
T250 = y(67)*exp(y(48))*exp(y(25))*exp(y(40))/(1-exp(y(25)));
T268 = 1-params(12)/2*y(37)^2;
T291 = exp(y(18))/exp(y(2));
T294 = exp(y(36))*(T268-params(12)*y(37)*T291);
T301 = exp(y(95))/exp(y(18));
T304 = exp(y(100))*T53*params(12)*y(101)*T301^2;
T353 = exp(y(98))*(1-exp(y(96)))*T183*params(2)*(1-params(5))*(1-params(13))*exp(y(22));
T361 = exp(y(48))*exp(y(41))/exp(y(20));
T409 = params(20)*params(9)^2;
T419 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T409)/(1-2*params(10)+params(10)^2));
T435 = 0.7071067811865475/params(9)*(params(8)+T409+(-log(exp(y(19))))+params(10)*log(exp(y(19)))-params(10)*params(8))/((-1)+params(10));
T455 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T457 = T419*(erf(T435)-erf(0.7071067811865475*(params(8)+T409+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T455/params(11)^0.5;
T477 = exp(y(46))*(1-params(10))*exp(y(35))/exp(y(14));
T480 = exp(y(19))/exp(y(24));
T489 = exp(y(46))*params(10)*exp(y(35))/exp(y(1));
T565 = exp(y(94))/exp(y(59));
T569 = T565-params(83)/params(80);
T662 = params(6)/(1-params(6));
T667 = exp(y(22))*y(67)*exp(y(105))*params(2)*(1-params(5))*(1-params(13))/exp(y(52));
T717 = (exp(y(47))+T163)*exp(y(41));
T879 = (-(exp(y(18))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T929 = (-(exp(y(48))*exp(y(20))))/(exp(y(20))*exp(y(20)));
T1082 = (-(params(2)*exp(y(105))*exp(y(52))))/(exp(y(52))*exp(y(52)));
T1087 = (-(exp(y(105))*exp(y(52))))/(exp(y(52))*exp(y(52)));
T1114 = (-(exp(y(94))*exp(y(59))))/(exp(y(59))*exp(y(59)));
lhs =y(50);
rhs =log(exp(y(13)));
residual(1)= lhs-rhs;
lhs =y(51);
rhs =y(50)+params(2)*y(104);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(48)))+(1-params(5))*(1-exp(y(25)))*exp(y(7))+(1-params(5))*(1-exp(y(25)))*exp(y(3))*exp(y(6));
residual(4) = (-params(17))/exp(y(20))+(1-params(5))*(1-params(13))*T53*((1-exp(y(96)))*exp(y(97))-exp(y(96))*y(67));
residual(5) = (-exp(y(54)))+exp(y(32))-params(17)/exp(y(20))-y(67);
residual(6) = (-exp(y(29)))+T90;
residual(7) = (-exp(y(32)))+exp(y(16))-params(6)*(exp(y(26))-exp(y(54)));
residual(8) = (-exp(y(46)))+T117*T121;
residual(9) = params(17)/exp(y(20))-exp(y(82));
residual(10) = (-exp(y(39)))+T134*exp(y(45))-exp(y(48))*exp(y(16))-params(17)*exp(y(47))-exp(y(27))*exp(y(49))-y(67)*exp(y(48))*exp(y(25))/(1-exp(y(25)));
residual(11) = (-exp(y(38)))+params(18)+y(68)+params(17)*(exp(y(47))+T163);
residual(12) = (-exp(y(45)))+exp(y(46))/exp(y(40));
residual(13) = (-T134)+exp(y(44))*exp(y(35));
residual(14) = (-exp(y(38)))+params(2)*(1-params(13))*T183*(exp(y(102))+exp(y(103)));
residual(15) = (-exp(y(40)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(16) = (-1)+T134*T210;
residual(17) = (-exp(y(44)))+exp(y(43))/(exp(y(43))-1);
residual(18) = (-exp(y(43)))+1+exp(y(40))*params(15);
residual(19) = (-exp(y(45)))+T230;
residual(20) = (-exp(y(33)))+exp(y(56))+exp(y(18))+params(17)*exp(y(15))+(params(18)+y(68))*exp(y(41))+T250+exp(y(69));
residual(21) = (-exp(y(17)))+exp(y(1))*(1-params(19))+exp(y(18))*T268;
residual(22) = (-exp(y(36)))+T53*(exp(y(99))*(1-exp(y(71)))+(1-params(19))*exp(y(100)));
residual(23) = (-1)+T294+T304;
residual(24) = T291-y(37)-1;
residual(25) = (-exp(y(52)))+params(2)*exp(y(105))*(1+exp(y(81)));
residual(26) = (1-params(5))*(1-params(13))*T53*((1-exp(y(96)))*exp(y(97))-exp(y(96))*y(106))+exp(y(26))-exp(y(28))-exp(y(16));
residual(27) = (-exp(y(30)))+(1-exp(y(70)))*exp(y(16))-exp(y(31))+(1-params(5))*(1-params(13))*T53*(1-exp(y(96)))*exp(y(98));
residual(28) = (-exp(y(31)))+params(23)+y(66)+T353;
residual(29) = (-exp(y(15)))+exp(y(47))*(exp(y(40))+exp(y(41)))+T361;
residual(30) = (-exp(y(48)))+exp(y(14))/exp(y(40));
residual(31) = (-exp(y(49)))+exp(y(1))/exp(y(40));
residual(32) = (-exp(y(21)))+params(16)*exp(y(15))^(1-params(7))*exp(y(23))^params(7);
residual(33) = 1-exp(y(23))-exp(y(14));
residual(34) = (-exp(y(22)))+exp(y(21))/exp(y(23));
residual(35) = (-exp(y(20)))+exp(y(21))/exp(y(15));
residual(36) = (-exp(y(53)))+T457/(1-exp(y(25)));
residual(37) = (-exp(y(24)))+exp(y(53))^((1-params(10))/params(20));
residual(38) = (-exp(y(25)))+0.5+0.5*erf(log(exp(y(19)))/(params(9)*1.414213562373095));
residual(39) = (-exp(y(26)))+T477;
residual(40) = (-exp(y(54)))+exp(y(26))*T480^params(21);
residual(41) = (-exp(y(27)))+T489;
residual(42) = y(67)+(-exp(y(29)))+exp(y(28));
residual(43) = exp(y(27))-exp(y(34));
residual(44) = exp(y(13))-exp(y(56))-params(23)*(1-exp(y(14)));
residual(45) = (-exp(y(52)))+exp(y(13))^(-params(1));
residual(46) = T183-exp(y(93));
residual(47) = (-y(58))+params(3)*y(8)-x(it_, 1);
residual(48) = (-y(66))+params(76);
residual(49) = (-y(67))+params(77);
residual(50) = (-y(68))+params(78);
residual(51) = (-y(69))+(1-params(24))*log(params(81))+params(24)*y(9)+x(it_, 2);
residual(52) = (-exp(y(70)))+(1-params(25))*params(82)+params(25)*exp(y(10))+(1-params(25))*params(31)*T569+x(it_, 3);
residual(53) = (-exp(y(71)))+(1-params(26))*params(84)+params(26)*exp(y(11))+T569*(1-params(26))*params(30)+x(it_, 4);
residual(54) = (1-exp(y(25)))*(1-params(5))*params(13)+(1-params(5))*exp(y(25))+params(5)-exp(y(55));
residual(55) = (-exp(y(59)))+exp(y(16))*exp(y(14))+exp(y(1))*exp(y(34))+exp(y(39))*exp(y(40));
residual(56) = (params(18)+y(68))*exp(y(41))-exp(y(57));
residual(57) = (-exp(y(60)))+exp(y(59))/T134;
residual(58) = (-exp(y(61)))+exp(y(56))/T134;
residual(59) = (-exp(y(62)))+exp(y(18))/T134;
residual(60) = (-exp(y(64)))+exp(y(16))/T134;
residual(61) = (-exp(y(65)))+exp(y(13))/T134;
residual(62) = (-exp(y(63)))+exp(y(57))/T134;
residual(63) = (-exp(y(72)))+exp(y(15))/exp(y(23));
residual(64) = T662*(params(17)*exp(y(72))+T667)+y(66)+params(23)-exp(y(73));
residual(65) = (1-params(5))*exp(y(25))+params(5)-exp(y(74));
residual(66) = 1-exp(y(75))-(1-params(13))*(1-exp(y(74)));
residual(67) = (-exp(y(83)))+exp(y(14))*(1-params(5))*exp(y(25));
residual(68) = (-exp(y(76)))+exp(y(14))*exp(y(75))-exp(y(20))*params(5)*exp(y(14));
residual(69) = (-exp(y(77)))+exp(y(20))*exp(y(15))-exp(y(20))*params(5)*exp(y(14));
residual(70) = exp(y(77))-exp(y(78))-exp(y(76));
residual(71) = (-exp(y(80)))+T717;
residual(72) = exp(y(15))-exp(y(79))-exp(y(80));
residual(73) = (-exp(y(84)))+exp(y(38))/T134;
residual(74) = (-exp(y(85)))+exp(y(39))/T134;
residual(75) = (-exp(y(86)))+exp(y(32))/T134;
residual(76) = (-exp(y(87)))+exp(y(14))*(1-exp(y(70)))*exp(y(16));
residual(77) = (-exp(y(88)))+exp(y(17))*(1-exp(y(71)))*exp(y(34));
residual(78) = (-exp(y(89)))+exp(y(40))*(exp(y(39))+exp(y(38)));
residual(79) = (-exp(y(90)))+exp(y(38))*(exp(y(40))+exp(y(41)));
residual(80) = exp(y(18))+exp(y(90))+exp(y(56))-exp(y(91));
residual(81) = (-exp(y(92)))+(exp(y(102))+exp(y(103)))/exp(y(38));
residual(82) = (-exp(y(69)))+exp(y(14))*exp(y(70))*exp(y(16))+exp(y(17))*exp(y(71))*exp(y(34))+exp(y(107))-exp(y(94))-exp(y(94))*exp(y(12));
if nargout >= 2,
  g1 = zeros(82, 111);

  %
  % Jacobian matrix
  %

  g1(1,13)=(-1);
  g1(1,50)=1;
  g1(2,50)=(-1);
  g1(2,51)=1;
  g1(2,104)=(-params(2));
  g1(3,3)=(1-params(5))*(1-exp(y(25)))*exp(y(3))*exp(y(6));
  g1(3,25)=exp(y(7))*(1-params(5))*(-exp(y(25)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(25)));
  g1(3,6)=(1-params(5))*(1-exp(y(25)))*exp(y(3))*exp(y(6));
  g1(3,7)=(1-params(5))*(1-exp(y(25)))*exp(y(7));
  g1(3,48)=(-exp(y(48)));
  g1(4,20)=(-((-params(17))*exp(y(20))))/(exp(y(20))*exp(y(20)));
  g1(4,96)=(1-params(5))*(1-params(13))*T53*(exp(y(97))*(-exp(y(96)))-exp(y(96))*y(67));
  g1(4,97)=(1-params(5))*(1-params(13))*T53*(1-exp(y(96)))*exp(y(97));
  g1(4,52)=((1-exp(y(96)))*exp(y(97))-exp(y(96))*y(67))*(1-params(5))*(1-params(13))*T1082;
  g1(4,105)=(1-params(5))*(1-params(13))*T53*((1-exp(y(96)))*exp(y(97))-exp(y(96))*y(67));
  g1(4,67)=(1-params(5))*(1-params(13))*T53*(-exp(y(96)));
  g1(5,20)=(-((-(params(17)*exp(y(20))))/(exp(y(20))*exp(y(20)))));
  g1(5,32)=exp(y(32));
  g1(5,54)=(-exp(y(54)));
  g1(5,67)=(-1);
  g1(6,29)=(-exp(y(29)));
  g1(6,30)=T90;
  g1(6,70)=(1-params(6))/params(6)*exp(y(30))*exp(y(70))/((1-exp(y(70)))*(1-exp(y(70))));
  g1(7,16)=exp(y(16));
  g1(7,26)=(-(params(6)*exp(y(26))));
  g1(7,32)=(-exp(y(32)));
  g1(7,54)=(-((-exp(y(54)))*params(6)));
  g1(8,14)=T117*exp(y(14))*getPowerDeriv(exp(y(14)),1-params(10),1);
  g1(8,1)=T121*exp(y(58))*exp(y(24))^params(20)*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
  g1(8,24)=T121*exp(y(1))^params(10)*exp(y(58))*exp(y(24))*getPowerDeriv(exp(y(24)),params(20),1);
  g1(8,46)=(-exp(y(46)));
  g1(8,58)=T117*T121;
  g1(9,20)=(-(params(17)*exp(y(20))))/(exp(y(20))*exp(y(20)));
  g1(9,82)=(-exp(y(82)));
  g1(10,16)=(-(exp(y(48))*exp(y(16))));
  g1(10,25)=(-(((1-exp(y(25)))*y(67)*exp(y(48))*exp(y(25))-y(67)*exp(y(48))*exp(y(25))*(-exp(y(25))))/((1-exp(y(25)))*(1-exp(y(25))))));
  g1(10,27)=(-(exp(y(27))*exp(y(49))));
  g1(10,39)=(-exp(y(39)));
  g1(10,42)=T134*exp(y(45));
  g1(10,45)=T134*exp(y(45));
  g1(10,47)=(-(params(17)*exp(y(47))));
  g1(10,48)=(-(exp(y(48))*exp(y(16))))-y(67)*exp(y(48))*exp(y(25))/(1-exp(y(25)));
  g1(10,49)=(-(exp(y(27))*exp(y(49))));
  g1(10,67)=(-(exp(y(48))*exp(y(25))/(1-exp(y(25)))));
  g1(11,20)=params(17)*T929;
  g1(11,38)=(-exp(y(38)));
  g1(11,47)=params(17)*exp(y(47));
  g1(11,48)=params(17)*T163;
  g1(11,68)=1;
  g1(12,40)=(-(exp(y(46))*exp(y(40))))/(exp(y(40))*exp(y(40)));
  g1(12,45)=(-exp(y(45)));
  g1(12,46)=exp(y(46))/exp(y(40));
  g1(13,35)=exp(y(44))*exp(y(35));
  g1(13,42)=(-T134);
  g1(13,44)=exp(y(44))*exp(y(35));
  g1(14,38)=(-exp(y(38)));
  g1(14,102)=params(2)*(1-params(13))*T183*exp(y(102));
  g1(14,103)=params(2)*(1-params(13))*T183*exp(y(103));
  g1(14,52)=(exp(y(102))+exp(y(103)))*params(2)*(1-params(13))*T1087;
  g1(14,105)=params(2)*(1-params(13))*T183*(exp(y(102))+exp(y(103)));
  g1(15,4)=(1-params(13))*exp(y(4));
  g1(15,40)=(-exp(y(40)));
  g1(15,5)=(1-params(13))*exp(y(5));
  g1(16,40)=T134*T210*(exp(y(40))*params(14)*params(15)*(-exp(y(40)))*.5-.5*(params(14)-exp(y(40)))*exp(y(40))*params(14)*params(15))/(exp(y(40))*params(14)*params(15)*exp(y(40))*params(14)*params(15));
  g1(16,42)=T134*T210;
  g1(17,43)=(exp(y(43))*(exp(y(43))-1)-exp(y(43))*exp(y(43)))/((exp(y(43))-1)*(exp(y(43))-1));
  g1(17,44)=(-exp(y(44)));
  g1(18,40)=exp(y(40))*params(15);
  g1(18,43)=(-exp(y(43)));
  g1(19,33)=T230;
  g1(19,40)=(-(exp(y(40))*1/T134*exp(y(33))))/(exp(y(40))*exp(y(40)));
  g1(19,42)=exp(y(33))*(-T134)/(T134*T134)/exp(y(40));
  g1(19,45)=(-exp(y(45)));
  g1(20,15)=params(17)*exp(y(15));
  g1(20,18)=exp(y(18));
  g1(20,25)=((1-exp(y(25)))*y(67)*exp(y(48))*exp(y(25))*exp(y(40))-y(67)*exp(y(48))*exp(y(25))*exp(y(40))*(-exp(y(25))))/((1-exp(y(25)))*(1-exp(y(25))));
  g1(20,33)=(-exp(y(33)));
  g1(20,40)=T250;
  g1(20,41)=(params(18)+y(68))*exp(y(41));
  g1(20,48)=T250;
  g1(20,56)=exp(y(56));
  g1(20,67)=exp(y(48))*exp(y(25))*exp(y(40))/(1-exp(y(25)));
  g1(20,68)=exp(y(41));
  g1(20,69)=exp(y(69));
  g1(21,1)=exp(y(1))*(1-params(19));
  g1(21,17)=(-exp(y(17)));
  g1(21,18)=exp(y(18))*T268;
  g1(21,37)=exp(y(18))*(-(params(12)/2*2*y(37)));
  g1(22,99)=T53*exp(y(99))*(1-exp(y(71)));
  g1(22,36)=(-exp(y(36)));
  g1(22,100)=T53*(1-params(19))*exp(y(100));
  g1(22,52)=(exp(y(99))*(1-exp(y(71)))+(1-params(19))*exp(y(100)))*T1082;
  g1(22,105)=T53*(exp(y(99))*(1-exp(y(71)))+(1-params(19))*exp(y(100)));
  g1(22,71)=T53*exp(y(99))*(-exp(y(71)));
  g1(23,2)=exp(y(36))*(-(params(12)*y(37)*T879));
  g1(23,18)=exp(y(36))*(-(params(12)*y(37)*T291))+exp(y(100))*T53*params(12)*y(101)*(-(exp(y(18))*exp(y(95))))/(exp(y(18))*exp(y(18)))*2*T301;
  g1(23,95)=exp(y(100))*T53*params(12)*y(101)*T301*2*T301;
  g1(23,36)=T294;
  g1(23,100)=T304;
  g1(23,37)=exp(y(36))*((-(params(12)/2*2*y(37)))-params(12)*T291);
  g1(23,101)=exp(y(100))*T53*params(12)*T301^2;
  g1(23,52)=y(101)*T301^2*exp(y(100))*params(12)*T1082;
  g1(23,105)=T304;
  g1(24,2)=T879;
  g1(24,18)=T291;
  g1(24,37)=(-1);
  g1(25,52)=(-exp(y(52)));
  g1(25,105)=params(2)*exp(y(105))*(1+exp(y(81)));
  g1(25,81)=params(2)*exp(y(105))*exp(y(81));
  g1(26,16)=(-exp(y(16)));
  g1(26,96)=(1-params(5))*(1-params(13))*T53*(exp(y(97))*(-exp(y(96)))-exp(y(96))*y(106));
  g1(26,26)=exp(y(26));
  g1(26,28)=(-exp(y(28)));
  g1(26,97)=(1-params(5))*(1-params(13))*T53*(1-exp(y(96)))*exp(y(97));
  g1(26,52)=((1-exp(y(96)))*exp(y(97))-exp(y(96))*y(106))*(1-params(5))*(1-params(13))*T1082;
  g1(26,105)=(1-params(5))*(1-params(13))*T53*((1-exp(y(96)))*exp(y(97))-exp(y(96))*y(106));
  g1(26,106)=(1-params(5))*(1-params(13))*T53*(-exp(y(96)));
  g1(27,16)=(1-exp(y(70)))*exp(y(16));
  g1(27,96)=exp(y(98))*(1-params(5))*(1-params(13))*T53*(-exp(y(96)));
  g1(27,30)=(-exp(y(30)));
  g1(27,98)=(1-params(5))*(1-params(13))*T53*(1-exp(y(96)))*exp(y(98));
  g1(27,31)=(-exp(y(31)));
  g1(27,52)=exp(y(98))*(1-exp(y(96)))*(1-params(5))*(1-params(13))*T1082;
  g1(27,105)=(1-params(5))*(1-params(13))*T53*(1-exp(y(96)))*exp(y(98));
  g1(27,70)=exp(y(16))*(-exp(y(70)));
  g1(28,22)=T353;
  g1(28,96)=exp(y(98))*T183*params(2)*(1-params(5))*(1-params(13))*exp(y(22))*(-exp(y(96)));
  g1(28,98)=T353;
  g1(28,31)=(-exp(y(31)));
  g1(28,52)=exp(y(98))*(1-exp(y(96)))*exp(y(22))*params(2)*(1-params(5))*(1-params(13))*T1087;
  g1(28,105)=T353;
  g1(28,66)=1;
  g1(29,15)=(-exp(y(15)));
  g1(29,20)=(-(exp(y(20))*exp(y(48))*exp(y(41))))/(exp(y(20))*exp(y(20)));
  g1(29,40)=exp(y(47))*exp(y(40));
  g1(29,41)=T361+exp(y(47))*exp(y(41));
  g1(29,47)=exp(y(47))*(exp(y(40))+exp(y(41)));
  g1(29,48)=T361;
  g1(30,14)=exp(y(14))/exp(y(40));
  g1(30,40)=(-(exp(y(14))*exp(y(40))))/(exp(y(40))*exp(y(40)));
  g1(30,48)=(-exp(y(48)));
  g1(31,1)=exp(y(1))/exp(y(40));
  g1(31,40)=(-(exp(y(1))*exp(y(40))))/(exp(y(40))*exp(y(40)));
  g1(31,49)=(-exp(y(49)));
  g1(32,15)=exp(y(23))^params(7)*params(16)*exp(y(15))*getPowerDeriv(exp(y(15)),1-params(7),1);
  g1(32,21)=(-exp(y(21)));
  g1(32,23)=params(16)*exp(y(15))^(1-params(7))*exp(y(23))*getPowerDeriv(exp(y(23)),params(7),1);
  g1(33,14)=(-exp(y(14)));
  g1(33,23)=(-exp(y(23)));
  g1(34,21)=exp(y(21))/exp(y(23));
  g1(34,22)=(-exp(y(22)));
  g1(34,23)=(-(exp(y(21))*exp(y(23))))/(exp(y(23))*exp(y(23)));
  g1(35,15)=(-(exp(y(15))*exp(y(21))))/(exp(y(15))*exp(y(15)));
  g1(35,20)=(-exp(y(20)));
  g1(35,21)=exp(y(21))/exp(y(15));
  g1(36,19)=T455*T419*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T435^2)*1.772453850905516)/params(11)^0.5/(1-exp(y(25)));
  g1(36,25)=(-(T457*(-exp(y(25)))))/((1-exp(y(25)))*(1-exp(y(25))));
  g1(36,53)=(-exp(y(53)));
  g1(37,24)=(-exp(y(24)));
  g1(37,53)=exp(y(53))*getPowerDeriv(exp(y(53)),(1-params(10))/params(20),1);
  g1(38,19)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(19)))/(params(9)*1.414213562373095))^2));
  g1(38,25)=(-exp(y(25)));
  g1(39,14)=(-(exp(y(14))*exp(y(46))*(1-params(10))*exp(y(35))))/(exp(y(14))*exp(y(14)));
  g1(39,26)=(-exp(y(26)));
  g1(39,35)=T477;
  g1(39,46)=T477;
  g1(40,19)=exp(y(26))*T480*getPowerDeriv(T480,params(21),1);
  g1(40,24)=exp(y(26))*getPowerDeriv(T480,params(21),1)*(-(exp(y(24))*exp(y(19))))/(exp(y(24))*exp(y(24)));
  g1(40,26)=exp(y(26))*T480^params(21);
  g1(40,54)=(-exp(y(54)));
  g1(41,1)=(-(exp(y(1))*exp(y(46))*params(10)*exp(y(35))))/(exp(y(1))*exp(y(1)));
  g1(41,27)=(-exp(y(27)));
  g1(41,35)=T489;
  g1(41,46)=T489;
  g1(42,28)=exp(y(28));
  g1(42,29)=(-exp(y(29)));
  g1(42,67)=1;
  g1(43,27)=exp(y(27));
  g1(43,34)=(-exp(y(34)));
  g1(44,13)=exp(y(13));
  g1(44,14)=(-(params(23)*(-exp(y(14)))));
  g1(44,56)=(-exp(y(56)));
  g1(45,13)=exp(y(13))*getPowerDeriv(exp(y(13)),(-params(1)),1);
  g1(45,52)=(-exp(y(52)));
  g1(46,52)=T1087;
  g1(46,105)=T183;
  g1(46,93)=(-exp(y(93)));
  g1(47,8)=params(3);
  g1(47,58)=(-1);
  g1(47,108)=(-1);
  g1(48,66)=(-1);
  g1(49,67)=(-1);
  g1(50,68)=(-1);
  g1(51,9)=params(24);
  g1(51,69)=(-1);
  g1(51,109)=1;
  g1(52,59)=(1-params(25))*params(31)*T1114;
  g1(52,10)=params(25)*exp(y(10));
  g1(52,70)=(-exp(y(70)));
  g1(52,94)=(1-params(25))*params(31)*T565;
  g1(52,110)=1;
  g1(53,59)=(1-params(26))*params(30)*T1114;
  g1(53,11)=params(26)*exp(y(11));
  g1(53,71)=(-exp(y(71)));
  g1(53,94)=T565*(1-params(26))*params(30);
  g1(53,111)=1;
  g1(54,25)=(1-params(5))*exp(y(25))+(-exp(y(25)))*(1-params(5))*params(13);
  g1(54,55)=(-exp(y(55)));
  g1(55,14)=exp(y(16))*exp(y(14));
  g1(55,16)=exp(y(16))*exp(y(14));
  g1(55,1)=exp(y(1))*exp(y(34));
  g1(55,34)=exp(y(1))*exp(y(34));
  g1(55,39)=exp(y(39))*exp(y(40));
  g1(55,40)=exp(y(39))*exp(y(40));
  g1(55,59)=(-exp(y(59)));
  g1(56,41)=(params(18)+y(68))*exp(y(41));
  g1(56,57)=(-exp(y(57)));
  g1(56,68)=exp(y(41));
  g1(57,42)=(-(T134*exp(y(59))))/(T134*T134);
  g1(57,59)=exp(y(59))/T134;
  g1(57,60)=(-exp(y(60)));
  g1(58,42)=(-(T134*exp(y(56))))/(T134*T134);
  g1(58,56)=exp(y(56))/T134;
  g1(58,61)=(-exp(y(61)));
  g1(59,18)=exp(y(18))/T134;
  g1(59,42)=(-(T134*exp(y(18))))/(T134*T134);
  g1(59,62)=(-exp(y(62)));
  g1(60,16)=exp(y(16))/T134;
  g1(60,42)=(-(exp(y(16))*T134))/(T134*T134);
  g1(60,64)=(-exp(y(64)));
  g1(61,13)=exp(y(13))/T134;
  g1(61,42)=(-(exp(y(13))*T134))/(T134*T134);
  g1(61,65)=(-exp(y(65)));
  g1(62,42)=(-(T134*exp(y(57))))/(T134*T134);
  g1(62,57)=exp(y(57))/T134;
  g1(62,63)=(-exp(y(63)));
  g1(63,15)=exp(y(15))/exp(y(23));
  g1(63,23)=(-(exp(y(15))*exp(y(23))))/(exp(y(23))*exp(y(23)));
  g1(63,72)=(-exp(y(72)));
  g1(64,22)=T662*T667;
  g1(64,52)=T662*exp(y(22))*y(67)*(-(exp(y(52))*exp(y(105))*params(2)*(1-params(5))*(1-params(13))))/(exp(y(52))*exp(y(52)));
  g1(64,105)=T662*T667;
  g1(64,66)=1;
  g1(64,67)=T662*exp(y(22))*exp(y(105))*params(2)*(1-params(5))*(1-params(13))/exp(y(52));
  g1(64,72)=T662*params(17)*exp(y(72));
  g1(64,73)=(-exp(y(73)));
  g1(65,25)=(1-params(5))*exp(y(25));
  g1(65,74)=(-exp(y(74)));
  g1(66,74)=(-((1-params(13))*(-exp(y(74)))));
  g1(66,75)=(-exp(y(75)));
  g1(67,14)=exp(y(14))*(1-params(5))*exp(y(25));
  g1(67,25)=exp(y(14))*(1-params(5))*exp(y(25));
  g1(67,83)=(-exp(y(83)));
  g1(68,14)=exp(y(14))*exp(y(75))-exp(y(20))*params(5)*exp(y(14));
  g1(68,20)=(-(exp(y(20))*params(5)*exp(y(14))));
  g1(68,75)=exp(y(14))*exp(y(75));
  g1(68,76)=(-exp(y(76)));
  g1(69,14)=(-(exp(y(20))*params(5)*exp(y(14))));
  g1(69,15)=exp(y(20))*exp(y(15));
  g1(69,20)=exp(y(20))*exp(y(15))-exp(y(20))*params(5)*exp(y(14));
  g1(69,77)=(-exp(y(77)));
  g1(70,76)=(-exp(y(76)));
  g1(70,77)=exp(y(77));
  g1(70,78)=(-exp(y(78)));
  g1(71,20)=exp(y(41))*T929;
  g1(71,41)=T717;
  g1(71,47)=exp(y(47))*exp(y(41));
  g1(71,48)=T163*exp(y(41));
  g1(71,80)=(-exp(y(80)));
  g1(72,15)=exp(y(15));
  g1(72,79)=(-exp(y(79)));
  g1(72,80)=(-exp(y(80)));
  g1(73,38)=exp(y(38))/T134;
  g1(73,42)=(-(T134*exp(y(38))))/(T134*T134);
  g1(73,84)=(-exp(y(84)));
  g1(74,39)=exp(y(39))/T134;
  g1(74,42)=(-(exp(y(39))*T134))/(T134*T134);
  g1(74,85)=(-exp(y(85)));
  g1(75,32)=exp(y(32))/T134;
  g1(75,42)=(-(exp(y(32))*T134))/(T134*T134);
  g1(75,86)=(-exp(y(86)));
  g1(76,14)=exp(y(14))*(1-exp(y(70)))*exp(y(16));
  g1(76,16)=exp(y(14))*(1-exp(y(70)))*exp(y(16));
  g1(76,70)=exp(y(14))*exp(y(16))*(-exp(y(70)));
  g1(76,87)=(-exp(y(87)));
  g1(77,17)=exp(y(17))*(1-exp(y(71)))*exp(y(34));
  g1(77,34)=exp(y(17))*(1-exp(y(71)))*exp(y(34));
  g1(77,71)=exp(y(17))*exp(y(34))*(-exp(y(71)));
  g1(77,88)=(-exp(y(88)));
  g1(78,38)=exp(y(38))*exp(y(40));
  g1(78,39)=exp(y(39))*exp(y(40));
  g1(78,40)=exp(y(40))*(exp(y(39))+exp(y(38)));
  g1(78,89)=(-exp(y(89)));
  g1(79,38)=exp(y(38))*(exp(y(40))+exp(y(41)));
  g1(79,40)=exp(y(38))*exp(y(40));
  g1(79,41)=exp(y(38))*exp(y(41));
  g1(79,90)=(-exp(y(90)));
  g1(80,18)=exp(y(18));
  g1(80,56)=exp(y(56));
  g1(80,90)=exp(y(90));
  g1(80,91)=(-exp(y(91)));
  g1(81,38)=(-(exp(y(38))*(exp(y(102))+exp(y(103)))))/(exp(y(38))*exp(y(38)));
  g1(81,102)=exp(y(102))/exp(y(38));
  g1(81,103)=exp(y(103))/exp(y(38));
  g1(81,92)=(-exp(y(92)));
  g1(82,14)=exp(y(14))*exp(y(70))*exp(y(16));
  g1(82,16)=exp(y(14))*exp(y(70))*exp(y(16));
  g1(82,17)=exp(y(17))*exp(y(71))*exp(y(34));
  g1(82,34)=exp(y(17))*exp(y(71))*exp(y(34));
  g1(82,69)=(-exp(y(69)));
  g1(82,70)=exp(y(14))*exp(y(70))*exp(y(16));
  g1(82,71)=exp(y(17))*exp(y(71))*exp(y(34));
  g1(82,12)=(-(exp(y(94))*exp(y(12))));
  g1(82,94)=(-exp(y(94)))-exp(y(94))*exp(y(12));
  g1(82,107)=exp(y(107));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],82,12321);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],82,1367631);
end
end
