function [residual, g1, g2, g3] = cycle_moments_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(59, 1);
T26 = 1-exp(y(24));
T37 = (1-params(5))*T26*exp(y(3))*exp(y(6));
T53 = params(2)*exp(y(81))/exp(y(51));
T64 = (1-params(5))*(1-params(13))*T53*((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(66));
T85 = (1-params(6))/params(6)*exp(y(29));
T90 = T85*1/(1-exp(y(69)));
T112 = exp(y(57))*exp(y(23))^params(20);
T116 = exp(y(1))^params(10);
T117 = T112*T116;
T121 = exp(y(13))^(1-params(10));
T166 = exp(y(45))/exp(y(39));
T179 = params(2)*(1-params(13))*exp(y(81))/exp(y(51));
T205 = exp(.5*(params(14)-exp(y(39)))/(exp(y(39))*params(14)*params(15)));
T225 = 1/exp(y(41))*exp(y(32))/exp(y(39));
T245 = y(66)*exp(y(47))*exp(y(24))*exp(y(39))/T26;
T263 = 1-params(12)/2*y(36)^2;
T286 = exp(y(17))/exp(y(2));
T289 = exp(y(35))*(T263-params(12)*y(36)*T286);
T296 = exp(y(71))/exp(y(17));
T298 = y(77)*T296^2;
T299 = exp(y(76))*T53*params(12)*T298;
T314 = (1-params(5))*(1-params(13))*T53*((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(82));
T326 = (1-params(5))*(1-params(13))*T53*(1-exp(y(72)))*exp(y(74));
T338 = exp(y(81))/exp(y(51))*params(2)*(1-params(5))*(1-params(13))*exp(y(21));
T340 = exp(y(74))*(1-exp(y(72)))*T338;
T348 = exp(y(47))*exp(y(40))/exp(y(19));
T351 = exp(y(13))/exp(y(39));
T355 = exp(y(1))/exp(y(39));
T365 = params(16)*exp(y(14))^(1-params(7));
T368 = exp(y(22))^params(7);
T377 = exp(y(20))/exp(y(22));
T381 = exp(y(20))/exp(y(14));
T390 = params(11)^0.5;
T396 = params(20)*params(9)^2;
T406 = (-0.5)*T390*exp(params(20)*0.5*(2*params(8)+T396)/(1-2*params(10)+params(10)^2));
T422 = 0.7071067811865475/params(9)*(params(8)+T396+(-log(exp(y(18))))+params(10)*log(exp(y(18)))-params(10)*params(8))/((-1)+params(10));
T442 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T444 = T406*(erf(T422)-erf(0.7071067811865475*(params(8)+T396+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T442/T390;
T455 = log(exp(y(18)))/(params(9)*1.414213562373095);
T464 = exp(y(45))*(1-params(10))*exp(y(34))/exp(y(13));
T467 = exp(y(18))/exp(y(23));
T470 = exp(y(25))*T467^params(21);
T476 = exp(y(45))*params(10)*exp(y(34))/exp(y(1));
T586 = exp(y(58))/exp(y(41));
T592 = exp(y(55))/exp(y(41));
T598 = exp(y(17))/exp(y(41));
T604 = exp(y(15))/exp(y(41));
T610 = exp(y(12))/exp(y(41));
T616 = exp(y(56))/exp(y(41));
T643 = exp(y(13))*getPowerDeriv(exp(y(13)),1-params(10),1);
T649 = (-(exp(y(13))*exp(y(45))*(1-params(10))*exp(y(34))))/(exp(y(13))*exp(y(13)));
T659 = (-(exp(y(14))*exp(y(20))))/(exp(y(14))*exp(y(14)));
T663 = exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
T664 = T112*T663;
T669 = (-(exp(y(1))*exp(y(45))*params(10)*exp(y(34))))/(exp(y(1))*exp(y(1)));
T673 = (-(exp(y(17))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T682 = (-(exp(y(17))*exp(y(71))))/(exp(y(17))*exp(y(17)));
T692 = 0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10));
T696 = exp(T422^2)*1.772453850905516;
T701 = T442*T406*T692*2/T696/T390;
T705 = exp(T455^2);
T715 = exp(y(19))*exp(y(19));
T727 = (-(exp(y(19))*exp(y(47))*exp(y(40))))/T715;
T729 = exp(y(22))*getPowerDeriv(exp(y(22)),params(7),1);
T734 = (-(exp(y(20))*exp(y(22))))/(exp(y(22))*exp(y(22)));
T737 = exp(y(57))*exp(y(23))*getPowerDeriv(exp(y(23)),params(20),1);
T738 = T116*T737;
T743 = (-(exp(y(23))*exp(y(18))))/(exp(y(23))*exp(y(23)));
T744 = getPowerDeriv(T467,params(21),1)*T743;
T754 = T26*T26;
T756 = (-((T26*y(66)*exp(y(47))*exp(y(24))-y(66)*exp(y(47))*exp(y(24))*(-exp(y(24))))/T754));
T758 = y(66)*exp(y(47))*exp(y(24))*exp(y(39))*(-exp(y(24)));
T760 = (T26*y(66)*exp(y(47))*exp(y(24))*exp(y(39))-T758)/T754;
T769 = (1-params(5))*(1-params(13))*T53*(exp(y(73))*(-exp(y(72)))-exp(y(72))*y(66));
T771 = (1-params(5))*(1-params(13))*T53*(exp(y(73))*(-exp(y(72)))-exp(y(72))*y(82));
T772 = (1-params(5))*(1-params(13))*T53*(-exp(y(72)));
T779 = (1-params(5))*(1-params(13))*T53*(1-exp(y(72)))*exp(y(73));
T789 = exp(y(76))*T53*params(12)*T296^2;
T795 = exp(y(39))*exp(y(39));
T801 = exp(y(39))*params(14)*params(15)*exp(y(39))*params(14)*params(15);
T802 = (exp(y(39))*params(14)*params(15)*(-exp(y(39)))*.5-.5*(params(14)-exp(y(39)))*exp(y(39))*params(14)*params(15))/T801;
T806 = (-(exp(y(39))*1/exp(y(41))*exp(y(32))));
T807 = T806/T795;
T818 = exp(y(41))*exp(y(41));
T820 = exp(y(32))*(-exp(y(41)))/T818;
T821 = T820/exp(y(39));
T846 = (-(exp(y(47))*exp(y(15))))-y(66)*exp(y(47))*exp(y(24))/T26;
T852 = (-(params(2)*exp(y(81))*exp(y(51))))/(exp(y(51))*exp(y(51)));
T857 = (-(exp(y(81))*exp(y(51))))/(exp(y(51))*exp(y(51)));
T870 = exp(y(74))*(1-exp(y(72)))*exp(y(21))*params(2)*(1-params(5))*(1-params(13))*T857;
T872 = exp(y(52))*getPowerDeriv(exp(y(52)),(1-params(10))/params(20),1);
T877 = exp(y(47))*exp(y(24))*exp(y(39))/T26;
T881 = T85*exp(y(69))/((1-exp(y(69)))*(1-exp(y(69))));
T900 = ((-(params(2)*exp(y(81))*exp(y(51))))*exp(y(51))*exp(y(51))-(-(params(2)*exp(y(81))*exp(y(51))))*(exp(y(51))*exp(y(51))+exp(y(51))*exp(y(51))))/(exp(y(51))*exp(y(51))*exp(y(51))*exp(y(51)));
T971 = (exp(y(51))*exp(y(51))*(-(exp(y(81))*exp(y(51))))-(-(exp(y(81))*exp(y(51))))*(exp(y(51))*exp(y(51))+exp(y(51))*exp(y(51))))/(exp(y(51))*exp(y(51))*exp(y(51))*exp(y(51)));
T1034 = ((-(exp(y(17))*exp(y(2))))*exp(y(2))*exp(y(2))-(-(exp(y(17))*exp(y(2))))*(exp(y(2))*exp(y(2))+exp(y(2))*exp(y(2))))/(exp(y(2))*exp(y(2))*exp(y(2))*exp(y(2)));
lhs =y(49);
rhs =log(exp(y(12)));
residual(1)= lhs-rhs;
lhs =y(50);
rhs =y(49)+params(2)*y(80);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(47)))+(1-params(5))*T26*exp(y(7))+T37;
residual(4) = (-params(17))/exp(y(19))+T64;
residual(5) = (-exp(y(53)))+exp(y(31))-params(17)/exp(y(19))-y(66);
residual(6) = (-exp(y(28)))+T90;
residual(7) = (-exp(y(31)))+exp(y(15))-params(6)*(exp(y(25))-exp(y(53)));
residual(8) = (-exp(y(45)))+T117*T121;
residual(9) = (-exp(y(38)))+exp(y(41))*exp(y(44))-exp(y(47))*exp(y(15))-params(17)*exp(y(46))-exp(y(26))*exp(y(48))-y(66)*exp(y(47))*exp(y(24))/T26;
residual(10) = (-exp(y(37)))+params(18)+y(67)+params(17)*(exp(y(46))+exp(y(47))/exp(y(19)));
residual(11) = (-exp(y(44)))+T166;
residual(12) = (-exp(y(41)))+exp(y(43))*exp(y(34));
residual(13) = (-exp(y(37)))+T179*(exp(y(78))+exp(y(79)));
residual(14) = (-exp(y(39)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(15) = (-1)+exp(y(41))*T205;
residual(16) = (-exp(y(43)))+exp(y(42))/(exp(y(42))-1);
residual(17) = (-exp(y(42)))+1+exp(y(39))*params(15);
residual(18) = (-exp(y(44)))+T225;
residual(19) = (-exp(y(32)))+exp(y(55))+exp(y(17))+params(17)*exp(y(14))+(params(18)+y(67))*exp(y(40))+T245+exp(y(68));
residual(20) = (-exp(y(16)))+exp(y(1))*(1-params(19))+exp(y(17))*T263;
residual(21) = (-exp(y(35)))+T53*(exp(y(75))*(1-exp(y(70)))+(1-params(19))*exp(y(76)));
residual(22) = (-1)+T289+T299;
residual(23) = T286-y(36)-1;
residual(24) = T314+exp(y(25))-exp(y(27))-exp(y(15));
residual(25) = (-exp(y(29)))+(1-exp(y(69)))*exp(y(15))-exp(y(30))+T326;
residual(26) = (-exp(y(30)))+params(23)+y(65)+T340;
residual(27) = (-exp(y(14)))+exp(y(46))*(exp(y(39))+exp(y(40)))+T348;
residual(28) = (-exp(y(47)))+T351;
residual(29) = (-exp(y(48)))+T355;
residual(30) = (-exp(y(20)))+T365*T368;
residual(31) = 1-exp(y(22))-exp(y(13));
residual(32) = (-exp(y(21)))+T377;
residual(33) = (-exp(y(19)))+T381;
residual(34) = (-exp(y(52)))+T444/T26;
residual(35) = (-exp(y(23)))+exp(y(52))^((1-params(10))/params(20));
residual(36) = (-exp(y(24)))+0.5+0.5*erf(T455);
residual(37) = (-exp(y(25)))+T464;
residual(38) = (-exp(y(53)))+T470;
residual(39) = (-exp(y(26)))+T476;
residual(40) = y(66)+(-exp(y(28)))+exp(y(27));
residual(41) = exp(y(26))-exp(y(33));
residual(42) = exp(y(12))-exp(y(55))-params(23)*(1-exp(y(13)));
residual(43) = (-exp(y(51)))+exp(y(12))^(-params(1));
residual(44) = (-y(57))+params(3)*y(8)-x(it_, 1);
residual(45) = (-y(65))+params(71);
residual(46) = (-y(66))+params(72);
residual(47) = (-y(67))+params(73);
residual(48) = (-y(68))+(1-params(24))*log(params(76))+params(24)*y(9)+x(it_, 2);
residual(49) = (-y(69))+(1-params(25))*log(params(77))+params(25)*y(10)+x(it_, 3);
residual(50) = (-y(70))+(1-params(26))*log(params(78))+params(26)*y(11)-x(it_, 4);
residual(51) = T26*(1-params(5))*params(13)+(1-params(5))*exp(y(24))+params(5)-exp(y(54));
residual(52) = (-exp(y(58)))+exp(y(15))*exp(y(13))+exp(y(1))*exp(y(33))+exp(y(38))*exp(y(39));
residual(53) = (params(18)+y(67))*exp(y(40))-exp(y(56));
residual(54) = (-exp(y(59)))+T586;
residual(55) = (-exp(y(60)))+T592;
residual(56) = (-exp(y(61)))+T598;
residual(57) = (-exp(y(63)))+T604;
residual(58) = (-exp(y(64)))+T610;
residual(59) = (-exp(y(62)))+T616;
if nargout >= 2,
  g1 = zeros(59, 86);

  %
  % Jacobian matrix
  %

  g1(1,12)=(-1);
  g1(1,49)=1;
  g1(2,49)=(-1);
  g1(2,50)=1;
  g1(2,80)=(-params(2));
  g1(3,3)=T37;
  g1(3,24)=exp(y(7))*(1-params(5))*(-exp(y(24)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(24)));
  g1(3,6)=T37;
  g1(3,7)=(1-params(5))*T26*exp(y(7));
  g1(3,47)=(-exp(y(47)));
  g1(4,19)=(-((-params(17))*exp(y(19))))/T715;
  g1(4,72)=T769;
  g1(4,73)=T779;
  g1(4,51)=((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(66))*(1-params(5))*(1-params(13))*T852;
  g1(4,81)=T64;
  g1(4,66)=T772;
  g1(5,19)=(-((-(params(17)*exp(y(19))))/T715));
  g1(5,31)=exp(y(31));
  g1(5,53)=(-exp(y(53)));
  g1(5,66)=(-1);
  g1(6,28)=(-exp(y(28)));
  g1(6,29)=T90;
  g1(6,69)=T881;
  g1(7,15)=exp(y(15));
  g1(7,25)=(-(params(6)*exp(y(25))));
  g1(7,31)=(-exp(y(31)));
  g1(7,53)=(-((-exp(y(53)))*params(6)));
  g1(8,13)=T117*T643;
  g1(8,1)=T121*T664;
  g1(8,23)=T121*T738;
  g1(8,45)=(-exp(y(45)));
  g1(8,57)=T117*T121;
  g1(9,15)=(-(exp(y(47))*exp(y(15))));
  g1(9,24)=T756;
  g1(9,26)=(-(exp(y(26))*exp(y(48))));
  g1(9,38)=(-exp(y(38)));
  g1(9,41)=exp(y(41))*exp(y(44));
  g1(9,44)=exp(y(41))*exp(y(44));
  g1(9,46)=(-(params(17)*exp(y(46))));
  g1(9,47)=T846;
  g1(9,48)=(-(exp(y(26))*exp(y(48))));
  g1(9,66)=(-(exp(y(47))*exp(y(24))/T26));
  g1(10,19)=params(17)*(-(exp(y(47))*exp(y(19))))/T715;
  g1(10,37)=(-exp(y(37)));
  g1(10,46)=params(17)*exp(y(46));
  g1(10,47)=params(17)*exp(y(47))/exp(y(19));
  g1(10,67)=1;
  g1(11,39)=(-(exp(y(45))*exp(y(39))))/T795;
  g1(11,44)=(-exp(y(44)));
  g1(11,45)=T166;
  g1(12,34)=exp(y(43))*exp(y(34));
  g1(12,41)=(-exp(y(41)));
  g1(12,43)=exp(y(43))*exp(y(34));
  g1(13,37)=(-exp(y(37)));
  g1(13,78)=T179*exp(y(78));
  g1(13,79)=T179*exp(y(79));
  g1(13,51)=(exp(y(78))+exp(y(79)))*params(2)*(1-params(13))*T857;
  g1(13,81)=T179*(exp(y(78))+exp(y(79)));
  g1(14,4)=(1-params(13))*exp(y(4));
  g1(14,39)=(-exp(y(39)));
  g1(14,5)=(1-params(13))*exp(y(5));
  g1(15,39)=exp(y(41))*T205*T802;
  g1(15,41)=exp(y(41))*T205;
  g1(16,42)=(exp(y(42))*(exp(y(42))-1)-exp(y(42))*exp(y(42)))/((exp(y(42))-1)*(exp(y(42))-1));
  g1(16,43)=(-exp(y(43)));
  g1(17,39)=exp(y(39))*params(15);
  g1(17,42)=(-exp(y(42)));
  g1(18,32)=T225;
  g1(18,39)=T807;
  g1(18,41)=T821;
  g1(18,44)=(-exp(y(44)));
  g1(19,14)=params(17)*exp(y(14));
  g1(19,17)=exp(y(17));
  g1(19,24)=T760;
  g1(19,32)=(-exp(y(32)));
  g1(19,39)=T245;
  g1(19,40)=(params(18)+y(67))*exp(y(40));
  g1(19,47)=T245;
  g1(19,55)=exp(y(55));
  g1(19,66)=T877;
  g1(19,67)=exp(y(40));
  g1(19,68)=exp(y(68));
  g1(20,1)=exp(y(1))*(1-params(19));
  g1(20,16)=(-exp(y(16)));
  g1(20,17)=exp(y(17))*T263;
  g1(20,36)=exp(y(17))*(-(params(12)/2*2*y(36)));
  g1(21,75)=T53*exp(y(75))*(1-exp(y(70)));
  g1(21,35)=(-exp(y(35)));
  g1(21,76)=T53*(1-params(19))*exp(y(76));
  g1(21,51)=(exp(y(75))*(1-exp(y(70)))+(1-params(19))*exp(y(76)))*T852;
  g1(21,81)=T53*(exp(y(75))*(1-exp(y(70)))+(1-params(19))*exp(y(76)));
  g1(21,70)=T53*exp(y(75))*(-exp(y(70)));
  g1(22,2)=exp(y(35))*(-(params(12)*y(36)*T673));
  g1(22,17)=exp(y(35))*(-(params(12)*y(36)*T286))+exp(y(76))*T53*params(12)*y(77)*T682*2*T296;
  g1(22,71)=exp(y(76))*T53*params(12)*y(77)*T296*2*T296;
  g1(22,35)=T289;
  g1(22,76)=T299;
  g1(22,36)=exp(y(35))*((-(params(12)/2*2*y(36)))-params(12)*T286);
  g1(22,77)=T789;
  g1(22,51)=T298*exp(y(76))*params(12)*T852;
  g1(22,81)=T299;
  g1(23,2)=T673;
  g1(23,17)=T286;
  g1(23,36)=(-1);
  g1(24,15)=(-exp(y(15)));
  g1(24,72)=T771;
  g1(24,25)=exp(y(25));
  g1(24,27)=(-exp(y(27)));
  g1(24,73)=T779;
  g1(24,51)=((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(82))*(1-params(5))*(1-params(13))*T852;
  g1(24,81)=T314;
  g1(24,82)=T772;
  g1(25,15)=(1-exp(y(69)))*exp(y(15));
  g1(25,72)=exp(y(74))*T772;
  g1(25,29)=(-exp(y(29)));
  g1(25,74)=T326;
  g1(25,30)=(-exp(y(30)));
  g1(25,51)=exp(y(74))*(1-exp(y(72)))*(1-params(5))*(1-params(13))*T852;
  g1(25,81)=T326;
  g1(25,69)=exp(y(15))*(-exp(y(69)));
  g1(26,21)=T340;
  g1(26,72)=exp(y(74))*T338*(-exp(y(72)));
  g1(26,74)=T340;
  g1(26,30)=(-exp(y(30)));
  g1(26,51)=T870;
  g1(26,81)=T340;
  g1(26,65)=1;
  g1(27,14)=(-exp(y(14)));
  g1(27,19)=T727;
  g1(27,39)=exp(y(46))*exp(y(39));
  g1(27,40)=T348+exp(y(46))*exp(y(40));
  g1(27,46)=exp(y(46))*(exp(y(39))+exp(y(40)));
  g1(27,47)=T348;
  g1(28,13)=T351;
  g1(28,39)=(-(exp(y(13))*exp(y(39))))/T795;
  g1(28,47)=(-exp(y(47)));
  g1(29,1)=T355;
  g1(29,39)=(-(exp(y(1))*exp(y(39))))/T795;
  g1(29,48)=(-exp(y(48)));
  g1(30,14)=T368*params(16)*exp(y(14))*getPowerDeriv(exp(y(14)),1-params(7),1);
  g1(30,20)=(-exp(y(20)));
  g1(30,22)=T365*T729;
  g1(31,13)=(-exp(y(13)));
  g1(31,22)=(-exp(y(22)));
  g1(32,20)=T377;
  g1(32,21)=(-exp(y(21)));
  g1(32,22)=T734;
  g1(33,14)=T659;
  g1(33,19)=(-exp(y(19)));
  g1(33,20)=T381;
  g1(34,18)=T701/T26;
  g1(34,24)=(-(T444*(-exp(y(24)))))/T754;
  g1(34,52)=(-exp(y(52)));
  g1(35,23)=(-exp(y(23)));
  g1(35,52)=T872;
  g1(36,18)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*T705);
  g1(36,24)=(-exp(y(24)));
  g1(37,13)=T649;
  g1(37,25)=(-exp(y(25)));
  g1(37,34)=T464;
  g1(37,45)=T464;
  g1(38,18)=exp(y(25))*T467*getPowerDeriv(T467,params(21),1);
  g1(38,23)=exp(y(25))*T744;
  g1(38,25)=T470;
  g1(38,53)=(-exp(y(53)));
  g1(39,1)=T669;
  g1(39,26)=(-exp(y(26)));
  g1(39,34)=T476;
  g1(39,45)=T476;
  g1(40,27)=exp(y(27));
  g1(40,28)=(-exp(y(28)));
  g1(40,66)=1;
  g1(41,26)=exp(y(26));
  g1(41,33)=(-exp(y(33)));
  g1(42,12)=exp(y(12));
  g1(42,13)=(-(params(23)*(-exp(y(13)))));
  g1(42,55)=(-exp(y(55)));
  g1(43,12)=exp(y(12))*getPowerDeriv(exp(y(12)),(-params(1)),1);
  g1(43,51)=(-exp(y(51)));
  g1(44,8)=params(3);
  g1(44,57)=(-1);
  g1(44,83)=(-1);
  g1(45,65)=(-1);
  g1(46,66)=(-1);
  g1(47,67)=(-1);
  g1(48,9)=params(24);
  g1(48,68)=(-1);
  g1(48,84)=1;
  g1(49,10)=params(25);
  g1(49,69)=(-1);
  g1(49,85)=1;
  g1(50,11)=params(26);
  g1(50,70)=(-1);
  g1(50,86)=(-1);
  g1(51,24)=(1-params(5))*exp(y(24))+(-exp(y(24)))*(1-params(5))*params(13);
  g1(51,54)=(-exp(y(54)));
  g1(52,13)=exp(y(15))*exp(y(13));
  g1(52,15)=exp(y(15))*exp(y(13));
  g1(52,1)=exp(y(1))*exp(y(33));
  g1(52,33)=exp(y(1))*exp(y(33));
  g1(52,38)=exp(y(38))*exp(y(39));
  g1(52,39)=exp(y(38))*exp(y(39));
  g1(52,58)=(-exp(y(58)));
  g1(53,40)=(params(18)+y(67))*exp(y(40));
  g1(53,56)=(-exp(y(56)));
  g1(53,67)=exp(y(40));
  g1(54,41)=(-(exp(y(41))*exp(y(58))))/T818;
  g1(54,58)=T586;
  g1(54,59)=(-exp(y(59)));
  g1(55,41)=(-(exp(y(41))*exp(y(55))))/T818;
  g1(55,55)=T592;
  g1(55,60)=(-exp(y(60)));
  g1(56,17)=T598;
  g1(56,41)=(-(exp(y(41))*exp(y(17))))/T818;
  g1(56,61)=(-exp(y(61)));
  g1(57,15)=T604;
  g1(57,41)=(-(exp(y(15))*exp(y(41))))/T818;
  g1(57,63)=(-exp(y(63)));
  g1(58,12)=T610;
  g1(58,41)=(-(exp(y(12))*exp(y(41))))/T818;
  g1(58,64)=(-exp(y(64)));
  g1(59,41)=(-(exp(y(41))*exp(y(56))))/T818;
  g1(59,56)=T616;
  g1(59,62)=(-exp(y(62)));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(456,3);
  v2(1,1)=3;
  v2(1,2)=175;
  v2(1,3)=T37;
  v2(2,1)=3;
  v2(2,2)=1981;
  v2(2,3)=exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(24)));
  v2(3,1)=3;
  v2(3,2)=196;
  v2(3,3)=  v2(2,3);
  v2(4,1)=3;
  v2(4,2)=2002;
  v2(4,3)=exp(y(7))*(1-params(5))*(-exp(y(24)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(24)));
  v2(5,1)=3;
  v2(5,2)=433;
  v2(5,3)=T37;
  v2(6,1)=3;
  v2(6,2)=178;
  v2(6,3)=  v2(5,3);
  v2(7,1)=3;
  v2(7,2)=454;
  v2(7,3)=exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(24)));
  v2(8,1)=3;
  v2(8,2)=1984;
  v2(8,3)=  v2(7,3);
  v2(9,1)=3;
  v2(9,2)=436;
  v2(9,3)=T37;
  v2(10,1)=3;
  v2(10,2)=540;
  v2(10,3)=exp(y(7))*(1-params(5))*(-exp(y(24)));
  v2(11,1)=3;
  v2(11,2)=1985;
  v2(11,3)=  v2(10,3);
  v2(12,1)=3;
  v2(12,2)=523;
  v2(12,3)=(1-params(5))*T26*exp(y(7));
  v2(13,1)=3;
  v2(13,2)=4003;
  v2(13,3)=(-exp(y(47)));
  v2(14,1)=4;
  v2(14,2)=1567;
  v2(14,3)=((-((-params(17))*exp(y(19))))*T715-(-((-params(17))*exp(y(19))))*(T715+T715))/(T715*T715);
  v2(15,1)=4;
  v2(15,2)=6178;
  v2(15,3)=T769;
  v2(16,1)=4;
  v2(16,2)=6264;
  v2(16,3)=(1-params(5))*(1-params(13))*T53*exp(y(73))*(-exp(y(72)));
  v2(17,1)=4;
  v2(17,2)=6179;
  v2(17,3)=  v2(16,3);
  v2(18,1)=4;
  v2(18,2)=6265;
  v2(18,3)=T779;
  v2(19,1)=4;
  v2(19,2)=4372;
  v2(19,3)=(exp(y(73))*(-exp(y(72)))-exp(y(72))*y(66))*(1-params(5))*(1-params(13))*T852;
  v2(20,1)=4;
  v2(20,2)=6157;
  v2(20,3)=  v2(19,3);
  v2(21,1)=4;
  v2(21,2)=4373;
  v2(21,3)=(1-exp(y(72)))*exp(y(73))*(1-params(5))*(1-params(13))*T852;
  v2(22,1)=4;
  v2(22,2)=6243;
  v2(22,3)=  v2(21,3);
  v2(23,1)=4;
  v2(23,2)=4351;
  v2(23,3)=((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(66))*(1-params(5))*(1-params(13))*T900;
  v2(24,1)=4;
  v2(24,2)=6952;
  v2(24,3)=T769;
  v2(25,1)=4;
  v2(25,2)=6187;
  v2(25,3)=  v2(24,3);
  v2(26,1)=4;
  v2(26,2)=6953;
  v2(26,3)=T779;
  v2(27,1)=4;
  v2(27,2)=6273;
  v2(27,3)=  v2(26,3);
  v2(28,1)=4;
  v2(28,2)=6931;
  v2(28,3)=((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(66))*(1-params(5))*(1-params(13))*T852;
  v2(29,1)=4;
  v2(29,2)=4381;
  v2(29,3)=  v2(28,3);
  v2(30,1)=4;
  v2(30,2)=6961;
  v2(30,3)=T64;
  v2(31,1)=4;
  v2(31,2)=5662;
  v2(31,3)=T772;
  v2(32,1)=4;
  v2(32,2)=6172;
  v2(32,3)=  v2(31,3);
  v2(33,1)=4;
  v2(33,2)=5641;
  v2(33,3)=(-exp(y(72)))*(1-params(5))*(1-params(13))*T852;
  v2(34,1)=4;
  v2(34,2)=4366;
  v2(34,3)=  v2(33,3);
  v2(35,1)=4;
  v2(35,2)=5671;
  v2(35,3)=T772;
  v2(36,1)=4;
  v2(36,2)=6946;
  v2(36,3)=  v2(35,3);
  v2(37,1)=5;
  v2(37,2)=1567;
  v2(37,3)=(-((T715*(-(params(17)*exp(y(19))))-(-(params(17)*exp(y(19))))*(T715+T715))/(T715*T715)));
  v2(38,1)=5;
  v2(38,2)=2611;
  v2(38,3)=exp(y(31));
  v2(39,1)=5;
  v2(39,2)=4525;
  v2(39,3)=(-exp(y(53)));
  v2(40,1)=6;
  v2(40,2)=2350;
  v2(40,3)=(-exp(y(28)));
  v2(41,1)=6;
  v2(41,2)=2437;
  v2(41,3)=T90;
  v2(42,1)=6;
  v2(42,2)=5877;
  v2(42,3)=T881;
  v2(43,1)=6;
  v2(43,2)=2477;
  v2(43,3)=  v2(42,3);
  v2(44,1)=6;
  v2(44,2)=5917;
  v2(44,3)=T85*(exp(y(69))*(1-exp(y(69)))*(1-exp(y(69)))-exp(y(69))*((1-exp(y(69)))*(-exp(y(69)))+(1-exp(y(69)))*(-exp(y(69)))))/((1-exp(y(69)))*(1-exp(y(69)))*(1-exp(y(69)))*(1-exp(y(69))));
  v2(45,1)=7;
  v2(45,2)=1219;
  v2(45,3)=exp(y(15));
  v2(46,1)=7;
  v2(46,2)=2089;
  v2(46,3)=(-(params(6)*exp(y(25))));
  v2(47,1)=7;
  v2(47,2)=2611;
  v2(47,3)=(-exp(y(31)));
  v2(48,1)=7;
  v2(48,2)=4525;
  v2(48,3)=(-((-exp(y(53)))*params(6)));
  v2(49,1)=8;
  v2(49,2)=1045;
  v2(49,3)=T117*(T643+exp(y(13))*exp(y(13))*getPowerDeriv(exp(y(13)),1-params(10),2));
  v2(50,1)=8;
  v2(50,2)=13;
  v2(50,3)=T643*T664;
  v2(51,1)=8;
  v2(51,2)=1033;
  v2(51,3)=  v2(50,3);
  v2(52,1)=8;
  v2(52,2)=1;
  v2(52,3)=T121*T112*(T663+exp(y(1))*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),2));
  v2(53,1)=8;
  v2(53,2)=1905;
  v2(53,3)=T643*T738;
  v2(54,1)=8;
  v2(54,2)=1055;
  v2(54,3)=  v2(53,3);
  v2(55,1)=8;
  v2(55,2)=1893;
  v2(55,3)=T121*T663*T737;
  v2(56,1)=8;
  v2(56,2)=23;
  v2(56,3)=  v2(55,3);
  v2(57,1)=8;
  v2(57,2)=1915;
  v2(57,3)=T121*T116*exp(y(57))*(exp(y(23))*getPowerDeriv(exp(y(23)),params(20),1)+exp(y(23))*exp(y(23))*getPowerDeriv(exp(y(23)),params(20),2));
  v2(58,1)=8;
  v2(58,2)=3829;
  v2(58,3)=(-exp(y(45)));
  v2(59,1)=8;
  v2(59,2)=4829;
  v2(59,3)=T117*T643;
  v2(60,1)=8;
  v2(60,2)=1089;
  v2(60,3)=  v2(59,3);
  v2(61,1)=8;
  v2(61,2)=4817;
  v2(61,3)=T121*T664;
  v2(62,1)=8;
  v2(62,2)=57;
  v2(62,3)=  v2(61,3);
  v2(63,1)=8;
  v2(63,2)=4839;
  v2(63,3)=T121*T738;
  v2(64,1)=8;
  v2(64,2)=1949;
  v2(64,3)=  v2(63,3);
  v2(65,1)=8;
  v2(65,2)=4873;
  v2(65,3)=T117*T121;
  v2(66,1)=9;
  v2(66,2)=1219;
  v2(66,3)=(-(exp(y(47))*exp(y(15))));
  v2(67,1)=9;
  v2(67,2)=2002;
  v2(67,3)=(-((T754*(T26*y(66)*exp(y(47))*exp(y(24))+y(66)*exp(y(47))*exp(y(24))*(-exp(y(24)))-(y(66)*exp(y(47))*exp(y(24))*(-exp(y(24)))+y(66)*exp(y(47))*exp(y(24))*(-exp(y(24)))))-(T26*y(66)*exp(y(47))*exp(y(24))-y(66)*exp(y(47))*exp(y(24))*(-exp(y(24))))*(T26*(-exp(y(24)))+T26*(-exp(y(24)))))/(T754*T754)));
  v2(68,1)=9;
  v2(68,2)=2176;
  v2(68,3)=(-(exp(y(26))*exp(y(48))));
  v2(69,1)=9;
  v2(69,2)=3220;
  v2(69,3)=(-exp(y(38)));
  v2(70,1)=9;
  v2(70,2)=3481;
  v2(70,3)=exp(y(41))*exp(y(44));
  v2(71,1)=9;
  v2(71,2)=3739;
  v2(71,3)=exp(y(41))*exp(y(44));
  v2(72,1)=9;
  v2(72,2)=3484;
  v2(72,3)=  v2(71,3);
  v2(73,1)=9;
  v2(73,2)=3742;
  v2(73,3)=exp(y(41))*exp(y(44));
  v2(74,1)=9;
  v2(74,2)=3916;
  v2(74,3)=(-(params(17)*exp(y(46))));
  v2(75,1)=9;
  v2(75,2)=3971;
  v2(75,3)=(-(exp(y(47))*exp(y(15))));
  v2(76,1)=9;
  v2(76,2)=1251;
  v2(76,3)=  v2(75,3);
  v2(77,1)=9;
  v2(77,2)=3980;
  v2(77,3)=T756;
  v2(78,1)=9;
  v2(78,2)=2025;
  v2(78,3)=  v2(77,3);
  v2(79,1)=9;
  v2(79,2)=4003;
  v2(79,3)=T846;
  v2(80,1)=9;
  v2(80,2)=4068;
  v2(80,3)=(-(exp(y(26))*exp(y(48))));
  v2(81,1)=9;
  v2(81,2)=2198;
  v2(81,3)=  v2(80,3);
  v2(82,1)=9;
  v2(82,2)=4090;
  v2(82,3)=(-(exp(y(26))*exp(y(48))));
  v2(83,1)=9;
  v2(83,2)=5614;
  v2(83,3)=(-((T26*exp(y(47))*exp(y(24))-exp(y(47))*exp(y(24))*(-exp(y(24))))/T754));
  v2(84,1)=9;
  v2(84,2)=2044;
  v2(84,3)=  v2(83,3);
  v2(85,1)=9;
  v2(85,2)=5637;
  v2(85,3)=(-(exp(y(47))*exp(y(24))/T26));
  v2(86,1)=9;
  v2(86,2)=4022;
  v2(86,3)=  v2(85,3);
  v2(87,1)=10;
  v2(87,2)=1567;
  v2(87,3)=params(17)*(T715*(-(exp(y(47))*exp(y(19))))-(-(exp(y(47))*exp(y(19))))*(T715+T715))/(T715*T715);
  v2(88,1)=10;
  v2(88,2)=3133;
  v2(88,3)=(-exp(y(37)));
  v2(89,1)=10;
  v2(89,2)=3916;
  v2(89,3)=params(17)*exp(y(46));
  v2(90,1)=10;
  v2(90,2)=3975;
  v2(90,3)=params(17)*(-(exp(y(47))*exp(y(19))))/T715;
  v2(91,1)=10;
  v2(91,2)=1595;
  v2(91,3)=  v2(90,3);
  v2(92,1)=10;
  v2(92,2)=4003;
  v2(92,3)=params(17)*exp(y(47))/exp(y(19));
  v2(93,1)=11;
  v2(93,2)=3307;
  v2(93,3)=((-(exp(y(45))*exp(y(39))))*T795-(-(exp(y(45))*exp(y(39))))*(T795+T795))/(T795*T795);
  v2(94,1)=11;
  v2(94,2)=3742;
  v2(94,3)=(-exp(y(44)));
  v2(95,1)=11;
  v2(95,2)=3823;
  v2(95,3)=(-(exp(y(45))*exp(y(39))))/T795;
  v2(96,1)=11;
  v2(96,2)=3313;
  v2(96,3)=  v2(95,3);
  v2(97,1)=11;
  v2(97,2)=3829;
  v2(97,3)=T166;
  v2(98,1)=12;
  v2(98,2)=2872;
  v2(98,3)=exp(y(43))*exp(y(34));
  v2(99,1)=12;
  v2(99,2)=3481;
  v2(99,3)=(-exp(y(41)));
  v2(100,1)=12;
  v2(100,2)=3646;
  v2(100,3)=exp(y(43))*exp(y(34));
  v2(101,1)=12;
  v2(101,2)=2881;
  v2(101,3)=  v2(100,3);
  v2(102,1)=12;
  v2(102,2)=3655;
  v2(102,3)=exp(y(43))*exp(y(34));
  v2(103,1)=13;
  v2(103,2)=3133;
  v2(103,3)=(-exp(y(37)));
  v2(104,1)=13;
  v2(104,2)=6700;
  v2(104,3)=T179*exp(y(78));
  v2(105,1)=13;
  v2(105,2)=6787;
  v2(105,3)=T179*exp(y(79));
  v2(106,1)=13;
  v2(106,2)=4378;
  v2(106,3)=exp(y(78))*params(2)*(1-params(13))*T857;
  v2(107,1)=13;
  v2(107,2)=6673;
  v2(107,3)=  v2(106,3);
  v2(108,1)=13;
  v2(108,2)=4379;
  v2(108,3)=exp(y(79))*params(2)*(1-params(13))*T857;
  v2(109,1)=13;
  v2(109,2)=6759;
  v2(109,3)=  v2(108,3);
  v2(110,1)=13;
  v2(110,2)=4351;
  v2(110,3)=(exp(y(78))+exp(y(79)))*params(2)*(1-params(13))*T971;
  v2(111,1)=13;
  v2(111,2)=6958;
  v2(111,3)=T179*exp(y(78));
  v2(112,1)=13;
  v2(112,2)=6703;
  v2(112,3)=  v2(111,3);
  v2(113,1)=13;
  v2(113,2)=6959;
  v2(113,3)=T179*exp(y(79));
  v2(114,1)=13;
  v2(114,2)=6789;
  v2(114,3)=  v2(113,3);
  v2(115,1)=13;
  v2(115,2)=6931;
  v2(115,3)=(exp(y(78))+exp(y(79)))*params(2)*(1-params(13))*T857;
  v2(116,1)=13;
  v2(116,2)=4381;
  v2(116,3)=  v2(115,3);
  v2(117,1)=13;
  v2(117,2)=6961;
  v2(117,3)=T179*(exp(y(78))+exp(y(79)));
  v2(118,1)=14;
  v2(118,2)=262;
  v2(118,3)=(1-params(13))*exp(y(4));
  v2(119,1)=14;
  v2(119,2)=3307;
  v2(119,3)=(-exp(y(39)));
  v2(120,1)=14;
  v2(120,2)=349;
  v2(120,3)=(1-params(13))*exp(y(5));
  v2(121,1)=15;
  v2(121,2)=3307;
  v2(121,3)=exp(y(41))*(T802*T205*T802+T205*(T801*(exp(y(39))*params(14)*params(15)*(-exp(y(39)))*.5+exp(y(39))*params(14)*params(15)*(-exp(y(39)))*.5-(exp(y(39))*params(14)*params(15)*(-exp(y(39)))*.5+.5*(params(14)-exp(y(39)))*exp(y(39))*params(14)*params(15)))-(exp(y(39))*params(14)*params(15)*(-exp(y(39)))*.5-.5*(params(14)-exp(y(39)))*exp(y(39))*params(14)*params(15))*(T801+T801))/(T801*T801));
  v2(122,1)=15;
  v2(122,2)=3479;
  v2(122,3)=exp(y(41))*T205*T802;
  v2(123,1)=15;
  v2(123,2)=3309;
  v2(123,3)=  v2(122,3);
  v2(124,1)=15;
  v2(124,2)=3481;
  v2(124,3)=exp(y(41))*T205;
  v2(125,1)=16;
  v2(125,2)=3568;
  v2(125,3)=((exp(y(42))-1)*(exp(y(42))-1)*(exp(y(42))*(exp(y(42))-1)+exp(y(42))*exp(y(42))-(exp(y(42))*exp(y(42))+exp(y(42))*exp(y(42))))-(exp(y(42))*(exp(y(42))-1)-exp(y(42))*exp(y(42)))*(exp(y(42))*(exp(y(42))-1)+exp(y(42))*(exp(y(42))-1)))/((exp(y(42))-1)*(exp(y(42))-1)*(exp(y(42))-1)*(exp(y(42))-1));
  v2(126,1)=16;
  v2(126,2)=3655;
  v2(126,3)=(-exp(y(43)));
  v2(127,1)=17;
  v2(127,2)=3307;
  v2(127,3)=exp(y(39))*params(15);
  v2(128,1)=17;
  v2(128,2)=3568;
  v2(128,3)=(-exp(y(42)));
  v2(129,1)=18;
  v2(129,2)=2698;
  v2(129,3)=T225;
  v2(130,1)=18;
  v2(130,2)=3300;
  v2(130,3)=T807;
  v2(131,1)=18;
  v2(131,2)=2705;
  v2(131,3)=  v2(130,3);
  v2(132,1)=18;
  v2(132,2)=3307;
  v2(132,3)=(T795*T806-T806*(T795+T795))/(T795*T795);
  v2(133,1)=18;
  v2(133,2)=3472;
  v2(133,3)=T821;
  v2(134,1)=18;
  v2(134,2)=2707;
  v2(134,3)=  v2(133,3);
  v2(135,1)=18;
  v2(135,2)=3479;
  v2(135,3)=(-(exp(y(39))*T820))/T795;
  v2(136,1)=18;
  v2(136,2)=3309;
  v2(136,3)=  v2(135,3);
  v2(137,1)=18;
  v2(137,2)=3481;
  v2(137,3)=exp(y(32))*((-exp(y(41)))*T818-(-exp(y(41)))*(T818+T818))/(T818*T818)/exp(y(39));
  v2(138,1)=18;
  v2(138,2)=3742;
  v2(138,3)=(-exp(y(44)));
  v2(139,1)=19;
  v2(139,2)=1132;
  v2(139,3)=params(17)*exp(y(14));
  v2(140,1)=19;
  v2(140,2)=1393;
  v2(140,3)=exp(y(17));
  v2(141,1)=19;
  v2(141,2)=2002;
  v2(141,3)=(T754*(T26*y(66)*exp(y(47))*exp(y(24))*exp(y(39))+T758-(T758+T758))-(T26*y(66)*exp(y(47))*exp(y(24))*exp(y(39))-T758)*(T26*(-exp(y(24)))+T26*(-exp(y(24)))))/(T754*T754);
  v2(142,1)=19;
  v2(142,2)=2698;
  v2(142,3)=(-exp(y(32)));
  v2(143,1)=19;
  v2(143,2)=3292;
  v2(143,3)=T760;
  v2(144,1)=19;
  v2(144,2)=2017;
  v2(144,3)=  v2(143,3);
  v2(145,1)=19;
  v2(145,2)=3307;
  v2(145,3)=T245;
  v2(146,1)=19;
  v2(146,2)=3394;
  v2(146,3)=(params(18)+y(67))*exp(y(40));
  v2(147,1)=19;
  v2(147,2)=3980;
  v2(147,3)=T760;
  v2(148,1)=19;
  v2(148,2)=2025;
  v2(148,3)=  v2(147,3);
  v2(149,1)=19;
  v2(149,2)=3995;
  v2(149,3)=T245;
  v2(150,1)=19;
  v2(150,2)=3315;
  v2(150,3)=  v2(149,3);
  v2(151,1)=19;
  v2(151,2)=4003;
  v2(151,3)=T245;
  v2(152,1)=19;
  v2(152,2)=4699;
  v2(152,3)=exp(y(55));
  v2(153,1)=19;
  v2(153,2)=5614;
  v2(153,3)=(T26*exp(y(47))*exp(y(24))*exp(y(39))-exp(y(47))*exp(y(24))*exp(y(39))*(-exp(y(24))))/T754;
  v2(154,1)=19;
  v2(154,2)=2044;
  v2(154,3)=  v2(153,3);
  v2(155,1)=19;
  v2(155,2)=5629;
  v2(155,3)=T877;
  v2(156,1)=19;
  v2(156,2)=3334;
  v2(156,3)=  v2(155,3);
  v2(157,1)=19;
  v2(157,2)=5637;
  v2(157,3)=T877;
  v2(158,1)=19;
  v2(158,2)=4022;
  v2(158,3)=  v2(157,3);
  v2(159,1)=19;
  v2(159,2)=5716;
  v2(159,3)=exp(y(40));
  v2(160,1)=19;
  v2(160,2)=3421;
  v2(160,3)=  v2(159,3);
  v2(161,1)=19;
  v2(161,2)=5830;
  v2(161,3)=exp(y(68));
  v2(162,1)=20;
  v2(162,2)=1;
  v2(162,3)=exp(y(1))*(1-params(19));
  v2(163,1)=20;
  v2(163,2)=1306;
  v2(163,3)=(-exp(y(16)));
  v2(164,1)=20;
  v2(164,2)=1393;
  v2(164,3)=exp(y(17))*T263;
  v2(165,1)=20;
  v2(165,2)=3027;
  v2(165,3)=exp(y(17))*(-(params(12)/2*2*y(36)));
  v2(166,1)=20;
  v2(166,2)=1412;
  v2(166,3)=  v2(165,3);
  v2(167,1)=20;
  v2(167,2)=3046;
  v2(167,3)=exp(y(17))*(-(2*params(12)/2));
  v2(168,1)=21;
  v2(168,2)=6439;
  v2(168,3)=T53*exp(y(75))*(1-exp(y(70)));
  v2(169,1)=21;
  v2(169,2)=2959;
  v2(169,3)=(-exp(y(35)));
  v2(170,1)=21;
  v2(170,2)=6526;
  v2(170,3)=T53*(1-params(19))*exp(y(76));
  v2(171,1)=21;
  v2(171,2)=4375;
  v2(171,3)=exp(y(75))*(1-exp(y(70)))*T852;
  v2(172,1)=21;
  v2(172,2)=6415;
  v2(172,3)=  v2(171,3);
  v2(173,1)=21;
  v2(173,2)=4376;
  v2(173,3)=(1-params(19))*exp(y(76))*T852;
  v2(174,1)=21;
  v2(174,2)=6501;
  v2(174,3)=  v2(173,3);
  v2(175,1)=21;
  v2(175,2)=4351;
  v2(175,3)=(exp(y(75))*(1-exp(y(70)))+(1-params(19))*exp(y(76)))*T900;
  v2(176,1)=21;
  v2(176,2)=6955;
  v2(176,3)=T53*exp(y(75))*(1-exp(y(70)));
  v2(177,1)=21;
  v2(177,2)=6445;
  v2(177,3)=  v2(176,3);
  v2(178,1)=21;
  v2(178,2)=6956;
  v2(178,3)=T53*(1-params(19))*exp(y(76));
  v2(179,1)=21;
  v2(179,2)=6531;
  v2(179,3)=  v2(178,3);
  v2(180,1)=21;
  v2(180,2)=6931;
  v2(180,3)=(exp(y(75))*(1-exp(y(70)))+(1-params(19))*exp(y(76)))*T852;
  v2(181,1)=21;
  v2(181,2)=4381;
  v2(181,3)=  v2(180,3);
  v2(182,1)=21;
  v2(182,2)=6961;
  v2(182,3)=T53*(exp(y(75))*(1-exp(y(70)))+(1-params(19))*exp(y(76)));
  v2(183,1)=21;
  v2(183,2)=6009;
  v2(183,3)=T53*exp(y(75))*(-exp(y(70)));
  v2(184,1)=21;
  v2(184,2)=6434;
  v2(184,3)=  v2(183,3);
  v2(185,1)=21;
  v2(185,2)=5985;
  v2(185,3)=T852*exp(y(75))*(-exp(y(70)));
  v2(186,1)=21;
  v2(186,2)=4370;
  v2(186,3)=  v2(185,3);
  v2(187,1)=21;
  v2(187,2)=6015;
  v2(187,3)=T53*exp(y(75))*(-exp(y(70)));
  v2(188,1)=21;
  v2(188,2)=6950;
  v2(188,3)=  v2(187,3);
  v2(189,1)=21;
  v2(189,2)=6004;
  v2(189,3)=T53*exp(y(75))*(-exp(y(70)));
  v2(190,1)=22;
  v2(190,2)=88;
  v2(190,3)=exp(y(35))*(-(params(12)*y(36)*T1034));
  v2(191,1)=22;
  v2(191,2)=1378;
  v2(191,3)=exp(y(35))*(-(params(12)*y(36)*T673));
  v2(192,1)=22;
  v2(192,2)=103;
  v2(192,3)=  v2(191,3);
  v2(193,1)=22;
  v2(193,2)=1393;
  v2(193,3)=exp(y(35))*(-(params(12)*y(36)*T286))+exp(y(76))*T53*params(12)*y(77)*(2*T296*((-(exp(y(17))*exp(y(71))))*exp(y(17))*exp(y(17))-(-(exp(y(17))*exp(y(71))))*(exp(y(17))*exp(y(17))+exp(y(17))*exp(y(17))))/(exp(y(17))*exp(y(17))*exp(y(17))*exp(y(17)))+T682*2*T682);
  v2(194,1)=22;
  v2(194,2)=6037;
  v2(194,3)=exp(y(76))*T53*params(12)*y(77)*(T682*2*T296+T296*2*T682);
  v2(195,1)=22;
  v2(195,2)=1447;
  v2(195,3)=  v2(194,3);
  v2(196,1)=22;
  v2(196,2)=6091;
  v2(196,3)=exp(y(76))*T53*params(12)*y(77)*(T296*2*T296+T296*2*T296);
  v2(197,1)=22;
  v2(197,2)=2926;
  v2(197,3)=exp(y(35))*(-(params(12)*y(36)*T673));
  v2(198,1)=22;
  v2(198,2)=121;
  v2(198,3)=  v2(197,3);
  v2(199,1)=22;
  v2(199,2)=2941;
  v2(199,3)=exp(y(35))*(-(params(12)*y(36)*T286));
  v2(200,1)=22;
  v2(200,2)=1411;
  v2(200,3)=  v2(199,3);
  v2(201,1)=22;
  v2(201,2)=2959;
  v2(201,3)=T289;
  v2(202,1)=22;
  v2(202,2)=6467;
  v2(202,3)=exp(y(76))*T53*params(12)*y(77)*T682*2*T296;
  v2(203,1)=22;
  v2(203,2)=1452;
  v2(203,3)=  v2(202,3);
  v2(204,1)=22;
  v2(204,2)=6521;
  v2(204,3)=exp(y(76))*T53*params(12)*y(77)*T296*2*T296;
  v2(205,1)=22;
  v2(205,2)=6096;
  v2(205,3)=  v2(204,3);
  v2(206,1)=22;
  v2(206,2)=6526;
  v2(206,3)=T299;
  v2(207,1)=22;
  v2(207,2)=3012;
  v2(207,3)=exp(y(35))*(-(params(12)*T673));
  v2(208,1)=22;
  v2(208,2)=122;
  v2(208,3)=  v2(207,3);
  v2(209,1)=22;
  v2(209,2)=3027;
  v2(209,3)=exp(y(35))*(-(params(12)*T286));
  v2(210,1)=22;
  v2(210,2)=1412;
  v2(210,3)=  v2(209,3);
  v2(211,1)=22;
  v2(211,2)=3045;
  v2(211,3)=exp(y(35))*((-(params(12)/2*2*y(36)))-params(12)*T286);
  v2(212,1)=22;
  v2(212,2)=2960;
  v2(212,3)=  v2(211,3);
  v2(213,1)=22;
  v2(213,2)=3046;
  v2(213,3)=exp(y(35))*(-(2*params(12)/2));
  v2(214,1)=22;
  v2(214,2)=6553;
  v2(214,3)=exp(y(76))*T53*params(12)*T682*2*T296;
  v2(215,1)=22;
  v2(215,2)=1453;
  v2(215,3)=  v2(214,3);
  v2(216,1)=22;
  v2(216,2)=6607;
  v2(216,3)=exp(y(76))*T53*params(12)*T296*2*T296;
  v2(217,1)=22;
  v2(217,2)=6097;
  v2(217,3)=  v2(216,3);
  v2(218,1)=22;
  v2(218,2)=6612;
  v2(218,3)=T789;
  v2(219,1)=22;
  v2(219,2)=6527;
  v2(219,3)=  v2(218,3);
  v2(220,1)=22;
  v2(220,2)=4317;
  v2(220,3)=y(77)*T682*2*T296*exp(y(76))*params(12)*T852;
  v2(221,1)=22;
  v2(221,2)=1427;
  v2(221,3)=  v2(220,3);
  v2(222,1)=22;
  v2(222,2)=4371;
  v2(222,3)=y(77)*T296*2*T296*exp(y(76))*params(12)*T852;
  v2(223,1)=22;
  v2(223,2)=6071;
  v2(223,3)=  v2(222,3);
  v2(224,1)=22;
  v2(224,2)=4376;
  v2(224,3)=T298*exp(y(76))*params(12)*T852;
  v2(225,1)=22;
  v2(225,2)=6501;
  v2(225,3)=  v2(224,3);
  v2(226,1)=22;
  v2(226,2)=4377;
  v2(226,3)=T296^2*exp(y(76))*params(12)*T852;
  v2(227,1)=22;
  v2(227,2)=6587;
  v2(227,3)=  v2(226,3);
  v2(228,1)=22;
  v2(228,2)=4351;
  v2(228,3)=T298*exp(y(76))*params(12)*T900;
  v2(229,1)=22;
  v2(229,2)=6897;
  v2(229,3)=exp(y(76))*T53*params(12)*y(77)*T682*2*T296;
  v2(230,1)=22;
  v2(230,2)=1457;
  v2(230,3)=  v2(229,3);
  v2(231,1)=22;
  v2(231,2)=6951;
  v2(231,3)=exp(y(76))*T53*params(12)*y(77)*T296*2*T296;
  v2(232,1)=22;
  v2(232,2)=6101;
  v2(232,3)=  v2(231,3);
  v2(233,1)=22;
  v2(233,2)=6956;
  v2(233,3)=T299;
  v2(234,1)=22;
  v2(234,2)=6531;
  v2(234,3)=  v2(233,3);
  v2(235,1)=22;
  v2(235,2)=6957;
  v2(235,3)=T789;
  v2(236,1)=22;
  v2(236,2)=6617;
  v2(236,3)=  v2(235,3);
  v2(237,1)=22;
  v2(237,2)=6931;
  v2(237,3)=T298*exp(y(76))*params(12)*T852;
  v2(238,1)=22;
  v2(238,2)=4381;
  v2(238,3)=  v2(237,3);
  v2(239,1)=22;
  v2(239,2)=6961;
  v2(239,3)=T299;
  v2(240,1)=23;
  v2(240,2)=88;
  v2(240,3)=T1034;
  v2(241,1)=23;
  v2(241,2)=1378;
  v2(241,3)=T673;
  v2(242,1)=23;
  v2(242,2)=103;
  v2(242,3)=  v2(241,3);
  v2(243,1)=23;
  v2(243,2)=1393;
  v2(243,3)=T286;
  v2(244,1)=24;
  v2(244,2)=1219;
  v2(244,3)=(-exp(y(15)));
  v2(245,1)=24;
  v2(245,2)=6178;
  v2(245,3)=T771;
  v2(246,1)=24;
  v2(246,2)=2089;
  v2(246,3)=exp(y(25));
  v2(247,1)=24;
  v2(247,2)=2263;
  v2(247,3)=(-exp(y(27)));
  v2(248,1)=24;
  v2(248,2)=6264;
  v2(248,3)=(1-params(5))*(1-params(13))*T53*exp(y(73))*(-exp(y(72)));
  v2(249,1)=24;
  v2(249,2)=6179;
  v2(249,3)=  v2(248,3);
  v2(250,1)=24;
  v2(250,2)=6265;
  v2(250,3)=T779;
  v2(251,1)=24;
  v2(251,2)=4372;
  v2(251,3)=(exp(y(73))*(-exp(y(72)))-exp(y(72))*y(82))*(1-params(5))*(1-params(13))*T852;
  v2(252,1)=24;
  v2(252,2)=6157;
  v2(252,3)=  v2(251,3);
  v2(253,1)=24;
  v2(253,2)=4373;
  v2(253,3)=(1-exp(y(72)))*exp(y(73))*(1-params(5))*(1-params(13))*T852;
  v2(254,1)=24;
  v2(254,2)=6243;
  v2(254,3)=  v2(253,3);
  v2(255,1)=24;
  v2(255,2)=4351;
  v2(255,3)=((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(82))*(1-params(5))*(1-params(13))*T900;
  v2(256,1)=24;
  v2(256,2)=6952;
  v2(256,3)=T771;
  v2(257,1)=24;
  v2(257,2)=6187;
  v2(257,3)=  v2(256,3);
  v2(258,1)=24;
  v2(258,2)=6953;
  v2(258,3)=T779;
  v2(259,1)=24;
  v2(259,2)=6273;
  v2(259,3)=  v2(258,3);
  v2(260,1)=24;
  v2(260,2)=6931;
  v2(260,3)=((1-exp(y(72)))*exp(y(73))-exp(y(72))*y(82))*(1-params(5))*(1-params(13))*T852;
  v2(261,1)=24;
  v2(261,2)=4381;
  v2(261,3)=  v2(260,3);
  v2(262,1)=24;
  v2(262,2)=6961;
  v2(262,3)=T314;
  v2(263,1)=24;
  v2(263,2)=7038;
  v2(263,3)=T772;
  v2(264,1)=24;
  v2(264,2)=6188;
  v2(264,3)=  v2(263,3);
  v2(265,1)=24;
  v2(265,2)=7017;
  v2(265,3)=(-exp(y(72)))*(1-params(5))*(1-params(13))*T852;
  v2(266,1)=24;
  v2(266,2)=4382;
  v2(266,3)=  v2(265,3);
  v2(267,1)=24;
  v2(267,2)=7047;
  v2(267,3)=T772;
  v2(268,1)=24;
  v2(268,2)=6962;
  v2(268,3)=  v2(267,3);
  v2(269,1)=25;
  v2(269,2)=1219;
  v2(269,3)=(1-exp(y(69)))*exp(y(15));
  v2(270,1)=25;
  v2(270,2)=6178;
  v2(270,3)=exp(y(74))*T772;
  v2(271,1)=25;
  v2(271,2)=2437;
  v2(271,3)=(-exp(y(29)));
  v2(272,1)=25;
  v2(272,2)=6350;
  v2(272,3)=exp(y(74))*T772;
  v2(273,1)=25;
  v2(273,2)=6180;
  v2(273,3)=  v2(272,3);
  v2(274,1)=25;
  v2(274,2)=6352;
  v2(274,3)=T326;
  v2(275,1)=25;
  v2(275,2)=2524;
  v2(275,3)=(-exp(y(30)));
  v2(276,1)=25;
  v2(276,2)=4372;
  v2(276,3)=exp(y(74))*(-exp(y(72)))*(1-params(5))*(1-params(13))*T852;
  v2(277,1)=25;
  v2(277,2)=6157;
  v2(277,3)=  v2(276,3);
  v2(278,1)=25;
  v2(278,2)=4374;
  v2(278,3)=exp(y(74))*(1-exp(y(72)))*(1-params(5))*(1-params(13))*T852;
  v2(279,1)=25;
  v2(279,2)=6329;
  v2(279,3)=  v2(278,3);
  v2(280,1)=25;
  v2(280,2)=4351;
  v2(280,3)=exp(y(74))*(1-exp(y(72)))*(1-params(5))*(1-params(13))*T900;
  v2(281,1)=25;
  v2(281,2)=6952;
  v2(281,3)=exp(y(74))*T772;
  v2(282,1)=25;
  v2(282,2)=6187;
  v2(282,3)=  v2(281,3);
  v2(283,1)=25;
  v2(283,2)=6954;
  v2(283,3)=T326;
  v2(284,1)=25;
  v2(284,2)=6359;
  v2(284,3)=  v2(283,3);
  v2(285,1)=25;
  v2(285,2)=6931;
  v2(285,3)=exp(y(74))*(1-exp(y(72)))*(1-params(5))*(1-params(13))*T852;
  v2(286,1)=25;
  v2(286,2)=4381;
  v2(286,3)=  v2(285,3);
  v2(287,1)=25;
  v2(287,2)=6961;
  v2(287,3)=T326;
  v2(288,1)=25;
  v2(288,2)=5863;
  v2(288,3)=exp(y(15))*(-exp(y(69)));
  v2(289,1)=25;
  v2(289,2)=1273;
  v2(289,3)=  v2(288,3);
  v2(290,1)=25;
  v2(290,2)=5917;
  v2(290,3)=exp(y(15))*(-exp(y(69)));
  v2(291,1)=26;
  v2(291,2)=1741;
  v2(291,3)=T340;
  v2(292,1)=26;
  v2(292,2)=6127;
  v2(292,3)=exp(y(74))*T338*(-exp(y(72)));
  v2(293,1)=26;
  v2(293,2)=1792;
  v2(293,3)=  v2(292,3);
  v2(294,1)=26;
  v2(294,2)=6178;
  v2(294,3)=exp(y(74))*T338*(-exp(y(72)));
  v2(295,1)=26;
  v2(295,2)=6299;
  v2(295,3)=T340;
  v2(296,1)=26;
  v2(296,2)=1794;
  v2(296,3)=  v2(295,3);
  v2(297,1)=26;
  v2(297,2)=6350;
  v2(297,3)=exp(y(74))*T338*(-exp(y(72)));
  v2(298,1)=26;
  v2(298,2)=6180;
  v2(298,3)=  v2(297,3);
  v2(299,1)=26;
  v2(299,2)=6352;
  v2(299,3)=T340;
  v2(300,1)=26;
  v2(300,2)=2524;
  v2(300,3)=(-exp(y(30)));
  v2(301,1)=26;
  v2(301,2)=4321;
  v2(301,3)=T870;
  v2(302,1)=26;
  v2(302,2)=1771;
  v2(302,3)=  v2(301,3);
  v2(303,1)=26;
  v2(303,2)=4372;
  v2(303,3)=exp(y(74))*(-exp(y(72)))*exp(y(21))*params(2)*(1-params(5))*(1-params(13))*T857;
  v2(304,1)=26;
  v2(304,2)=6157;
  v2(304,3)=  v2(303,3);
  v2(305,1)=26;
  v2(305,2)=4374;
  v2(305,3)=T870;
  v2(306,1)=26;
  v2(306,2)=6329;
  v2(306,3)=  v2(305,3);
  v2(307,1)=26;
  v2(307,2)=4351;
  v2(307,3)=exp(y(74))*(1-exp(y(72)))*exp(y(21))*params(2)*(1-params(5))*(1-params(13))*T971;
  v2(308,1)=26;
  v2(308,2)=6901;
  v2(308,3)=T340;
  v2(309,1)=26;
  v2(309,2)=1801;
  v2(309,3)=  v2(308,3);
  v2(310,1)=26;
  v2(310,2)=6952;
  v2(310,3)=exp(y(74))*T338*(-exp(y(72)));
  v2(311,1)=26;
  v2(311,2)=6187;
  v2(311,3)=  v2(310,3);
  v2(312,1)=26;
  v2(312,2)=6954;
  v2(312,3)=T340;
  v2(313,1)=26;
  v2(313,2)=6359;
  v2(313,3)=  v2(312,3);
  v2(314,1)=26;
  v2(314,2)=6931;
  v2(314,3)=T870;
  v2(315,1)=26;
  v2(315,2)=4381;
  v2(315,3)=  v2(314,3);
  v2(316,1)=26;
  v2(316,2)=6961;
  v2(316,3)=T340;
  v2(317,1)=27;
  v2(317,2)=1132;
  v2(317,3)=(-exp(y(14)));
  v2(318,1)=27;
  v2(318,2)=1567;
  v2(318,3)=(T715*(-(exp(y(19))*exp(y(47))*exp(y(40))))-(-(exp(y(19))*exp(y(47))*exp(y(40))))*(T715+T715))/(T715*T715);
  v2(319,1)=27;
  v2(319,2)=3307;
  v2(319,3)=exp(y(46))*exp(y(39));
  v2(320,1)=27;
  v2(320,2)=3373;
  v2(320,3)=T727;
  v2(321,1)=27;
  v2(321,2)=1588;
  v2(321,3)=  v2(320,3);
  v2(322,1)=27;
  v2(322,2)=3394;
  v2(322,3)=T348+exp(y(46))*exp(y(40));
  v2(323,1)=27;
  v2(323,2)=3909;
  v2(323,3)=exp(y(46))*exp(y(39));
  v2(324,1)=27;
  v2(324,2)=3314;
  v2(324,3)=  v2(323,3);
  v2(325,1)=27;
  v2(325,2)=3910;
  v2(325,3)=exp(y(46))*exp(y(40));
  v2(326,1)=27;
  v2(326,2)=3400;
  v2(326,3)=  v2(325,3);
  v2(327,1)=27;
  v2(327,2)=3916;
  v2(327,3)=exp(y(46))*(exp(y(39))+exp(y(40)));
  v2(328,1)=27;
  v2(328,2)=3975;
  v2(328,3)=T727;
  v2(329,1)=27;
  v2(329,2)=1595;
  v2(329,3)=  v2(328,3);
  v2(330,1)=27;
  v2(330,2)=3996;
  v2(330,3)=T348;
  v2(331,1)=27;
  v2(331,2)=3401;
  v2(331,3)=  v2(330,3);
  v2(332,1)=27;
  v2(332,2)=4003;
  v2(332,3)=T348;
  v2(333,1)=28;
  v2(333,2)=1045;
  v2(333,3)=T351;
  v2(334,1)=28;
  v2(334,2)=3281;
  v2(334,3)=(-(exp(y(13))*exp(y(39))))/T795;
  v2(335,1)=28;
  v2(335,2)=1071;
  v2(335,3)=  v2(334,3);
  v2(336,1)=28;
  v2(336,2)=3307;
  v2(336,3)=(T795*(-(exp(y(13))*exp(y(39))))-(-(exp(y(13))*exp(y(39))))*(T795+T795))/(T795*T795);
  v2(337,1)=28;
  v2(337,2)=4003;
  v2(337,3)=(-exp(y(47)));
  v2(338,1)=29;
  v2(338,2)=1;
  v2(338,3)=T355;
  v2(339,1)=29;
  v2(339,2)=3269;
  v2(339,3)=(-(exp(y(1))*exp(y(39))))/T795;
  v2(340,1)=29;
  v2(340,2)=39;
  v2(340,3)=  v2(339,3);
  v2(341,1)=29;
  v2(341,2)=3307;
  v2(341,3)=(T795*(-(exp(y(1))*exp(y(39))))-(-(exp(y(1))*exp(y(39))))*(T795+T795))/(T795*T795);
  v2(342,1)=29;
  v2(342,2)=4090;
  v2(342,3)=(-exp(y(48)));
  v2(343,1)=30;
  v2(343,2)=1132;
  v2(343,3)=T368*params(16)*(exp(y(14))*getPowerDeriv(exp(y(14)),1-params(7),1)+exp(y(14))*exp(y(14))*getPowerDeriv(exp(y(14)),1-params(7),2));
  v2(344,1)=30;
  v2(344,2)=1654;
  v2(344,3)=(-exp(y(20)));
  v2(345,1)=30;
  v2(345,2)=1820;
  v2(345,3)=params(16)*exp(y(14))*getPowerDeriv(exp(y(14)),1-params(7),1)*T729;
  v2(346,1)=30;
  v2(346,2)=1140;
  v2(346,3)=  v2(345,3);
  v2(347,1)=30;
  v2(347,2)=1828;
  v2(347,3)=T365*(T729+exp(y(22))*exp(y(22))*getPowerDeriv(exp(y(22)),params(7),2));
  v2(348,1)=31;
  v2(348,2)=1045;
  v2(348,3)=(-exp(y(13)));
  v2(349,1)=31;
  v2(349,2)=1828;
  v2(349,3)=(-exp(y(22)));
  v2(350,1)=32;
  v2(350,2)=1654;
  v2(350,3)=T377;
  v2(351,1)=32;
  v2(351,2)=1741;
  v2(351,3)=(-exp(y(21)));
  v2(352,1)=32;
  v2(352,2)=1826;
  v2(352,3)=T734;
  v2(353,1)=32;
  v2(353,2)=1656;
  v2(353,3)=  v2(352,3);
  v2(354,1)=32;
  v2(354,2)=1828;
  v2(354,3)=((-(exp(y(20))*exp(y(22))))*exp(y(22))*exp(y(22))-(-(exp(y(20))*exp(y(22))))*(exp(y(22))*exp(y(22))+exp(y(22))*exp(y(22))))/(exp(y(22))*exp(y(22))*exp(y(22))*exp(y(22)));
  v2(355,1)=33;
  v2(355,2)=1132;
  v2(355,3)=((-(exp(y(14))*exp(y(20))))*exp(y(14))*exp(y(14))-(-(exp(y(14))*exp(y(20))))*(exp(y(14))*exp(y(14))+exp(y(14))*exp(y(14))))/(exp(y(14))*exp(y(14))*exp(y(14))*exp(y(14)));
  v2(356,1)=33;
  v2(356,2)=1567;
  v2(356,3)=(-exp(y(19)));
  v2(357,1)=33;
  v2(357,2)=1648;
  v2(357,3)=T659;
  v2(358,1)=33;
  v2(358,2)=1138;
  v2(358,3)=  v2(357,3);
  v2(359,1)=33;
  v2(359,2)=1654;
  v2(359,3)=T381;
  v2(360,1)=34;
  v2(360,2)=1480;
  v2(360,3)=T442*T406*T692*(-(2*1.772453850905516*exp(T422^2)*T692*2*T422))/(T696*T696)/T390/T26;
  v2(361,1)=34;
  v2(361,2)=1996;
  v2(361,3)=(-((-exp(y(24)))*T701))/T754;
  v2(362,1)=34;
  v2(362,2)=1486;
  v2(362,3)=  v2(361,3);
  v2(363,1)=34;
  v2(363,2)=2002;
  v2(363,3)=(T754*(-(T444*(-exp(y(24)))))-(-(T444*(-exp(y(24)))))*(T26*(-exp(y(24)))+T26*(-exp(y(24)))))/(T754*T754);
  v2(364,1)=34;
  v2(364,2)=4438;
  v2(364,3)=(-exp(y(52)));
  v2(365,1)=35;
  v2(365,2)=1915;
  v2(365,3)=(-exp(y(23)));
  v2(366,1)=35;
  v2(366,2)=4438;
  v2(366,3)=T872+exp(y(52))*exp(y(52))*getPowerDeriv(exp(y(52)),(1-params(10))/params(20),2);
  v2(367,1)=36;
  v2(367,2)=1480;
  v2(367,3)=0.5*1/(params(9)*1.414213562373095)*(-(2*1.772453850905516*T705*1/(params(9)*1.414213562373095)*2*T455))/(1.772453850905516*T705*1.772453850905516*T705);
  v2(368,1)=36;
  v2(368,2)=2002;
  v2(368,3)=(-exp(y(24)));
  v2(369,1)=37;
  v2(369,2)=1045;
  v2(369,3)=((-(exp(y(13))*exp(y(45))*(1-params(10))*exp(y(34))))*exp(y(13))*exp(y(13))-(-(exp(y(13))*exp(y(45))*(1-params(10))*exp(y(34))))*(exp(y(13))*exp(y(13))+exp(y(13))*exp(y(13))))/(exp(y(13))*exp(y(13))*exp(y(13))*exp(y(13)));
  v2(370,1)=37;
  v2(370,2)=2089;
  v2(370,3)=(-exp(y(25)));
  v2(371,1)=37;
  v2(371,2)=2851;
  v2(371,3)=T649;
  v2(372,1)=37;
  v2(372,2)=1066;
  v2(372,3)=  v2(371,3);
  v2(373,1)=37;
  v2(373,2)=2872;
  v2(373,3)=T464;
  v2(374,1)=37;
  v2(374,2)=3797;
  v2(374,3)=T649;
  v2(375,1)=37;
  v2(375,2)=1077;
  v2(375,3)=  v2(374,3);
  v2(376,1)=37;
  v2(376,2)=3818;
  v2(376,3)=T464;
  v2(377,1)=37;
  v2(377,2)=2883;
  v2(377,3)=  v2(376,3);
  v2(378,1)=37;
  v2(378,2)=3829;
  v2(378,3)=T464;
  v2(379,1)=38;
  v2(379,2)=1480;
  v2(379,3)=exp(y(25))*(T467*getPowerDeriv(T467,params(21),1)+T467*T467*getPowerDeriv(T467,params(21),2));
  v2(380,1)=38;
  v2(380,2)=1910;
  v2(380,3)=exp(y(25))*(T744+T743*T467*getPowerDeriv(T467,params(21),2));
  v2(381,1)=38;
  v2(381,2)=1485;
  v2(381,3)=  v2(380,3);
  v2(382,1)=38;
  v2(382,2)=1915;
  v2(382,3)=exp(y(25))*(T743*T743*getPowerDeriv(T467,params(21),2)+getPowerDeriv(T467,params(21),1)*((-(exp(y(23))*exp(y(18))))*exp(y(23))*exp(y(23))-(-(exp(y(23))*exp(y(18))))*(exp(y(23))*exp(y(23))+exp(y(23))*exp(y(23))))/(exp(y(23))*exp(y(23))*exp(y(23))*exp(y(23))));
  v2(383,1)=38;
  v2(383,2)=2082;
  v2(383,3)=exp(y(25))*T467*getPowerDeriv(T467,params(21),1);
  v2(384,1)=38;
  v2(384,2)=1487;
  v2(384,3)=  v2(383,3);
  v2(385,1)=38;
  v2(385,2)=2087;
  v2(385,3)=exp(y(25))*T744;
  v2(386,1)=38;
  v2(386,2)=1917;
  v2(386,3)=  v2(385,3);
  v2(387,1)=38;
  v2(387,2)=2089;
  v2(387,3)=T470;
  v2(388,1)=38;
  v2(388,2)=4525;
  v2(388,3)=(-exp(y(53)));
  v2(389,1)=39;
  v2(389,2)=1;
  v2(389,3)=((-(exp(y(1))*exp(y(45))*params(10)*exp(y(34))))*exp(y(1))*exp(y(1))-(-(exp(y(1))*exp(y(45))*params(10)*exp(y(34))))*(exp(y(1))*exp(y(1))+exp(y(1))*exp(y(1))))/(exp(y(1))*exp(y(1))*exp(y(1))*exp(y(1)));
  v2(390,1)=39;
  v2(390,2)=2176;
  v2(390,3)=(-exp(y(26)));
  v2(391,1)=39;
  v2(391,2)=2839;
  v2(391,3)=T669;
  v2(392,1)=39;
  v2(392,2)=34;
  v2(392,3)=  v2(391,3);
  v2(393,1)=39;
  v2(393,2)=2872;
  v2(393,3)=T476;
  v2(394,1)=39;
  v2(394,2)=3785;
  v2(394,3)=T669;
  v2(395,1)=39;
  v2(395,2)=45;
  v2(395,3)=  v2(394,3);
  v2(396,1)=39;
  v2(396,2)=3818;
  v2(396,3)=T476;
  v2(397,1)=39;
  v2(397,2)=2883;
  v2(397,3)=  v2(396,3);
  v2(398,1)=39;
  v2(398,2)=3829;
  v2(398,3)=T476;
  v2(399,1)=40;
  v2(399,2)=2263;
  v2(399,3)=exp(y(27));
  v2(400,1)=40;
  v2(400,2)=2350;
  v2(400,3)=(-exp(y(28)));
  v2(401,1)=41;
  v2(401,2)=2176;
  v2(401,3)=exp(y(26));
  v2(402,1)=41;
  v2(402,2)=2785;
  v2(402,3)=(-exp(y(33)));
  v2(403,1)=42;
  v2(403,2)=958;
  v2(403,3)=exp(y(12));
  v2(404,1)=42;
  v2(404,2)=1045;
  v2(404,3)=(-(params(23)*(-exp(y(13)))));
  v2(405,1)=42;
  v2(405,2)=4699;
  v2(405,3)=(-exp(y(55)));
  v2(406,1)=43;
  v2(406,2)=958;
  v2(406,3)=exp(y(12))*getPowerDeriv(exp(y(12)),(-params(1)),1)+exp(y(12))*exp(y(12))*getPowerDeriv(exp(y(12)),(-params(1)),2);
  v2(407,1)=43;
  v2(407,2)=4351;
  v2(407,3)=(-exp(y(51)));
  v2(408,1)=51;
  v2(408,2)=2002;
  v2(408,3)=(1-params(5))*exp(y(24))+(-exp(y(24)))*(1-params(5))*params(13);
  v2(409,1)=51;
  v2(409,2)=4612;
  v2(409,3)=(-exp(y(54)));
  v2(410,1)=52;
  v2(410,2)=1045;
  v2(410,3)=exp(y(15))*exp(y(13));
  v2(411,1)=52;
  v2(411,2)=1217;
  v2(411,3)=exp(y(15))*exp(y(13));
  v2(412,1)=52;
  v2(412,2)=1047;
  v2(412,3)=  v2(411,3);
  v2(413,1)=52;
  v2(413,2)=1219;
  v2(413,3)=exp(y(15))*exp(y(13));
  v2(414,1)=52;
  v2(414,2)=1;
  v2(414,3)=exp(y(1))*exp(y(33));
  v2(415,1)=52;
  v2(415,2)=2753;
  v2(415,3)=exp(y(1))*exp(y(33));
  v2(416,1)=52;
  v2(416,2)=33;
  v2(416,3)=  v2(415,3);
  v2(417,1)=52;
  v2(417,2)=2785;
  v2(417,3)=exp(y(1))*exp(y(33));
  v2(418,1)=52;
  v2(418,2)=3220;
  v2(418,3)=exp(y(38))*exp(y(39));
  v2(419,1)=52;
  v2(419,2)=3306;
  v2(419,3)=exp(y(38))*exp(y(39));
  v2(420,1)=52;
  v2(420,2)=3221;
  v2(420,3)=  v2(419,3);
  v2(421,1)=52;
  v2(421,2)=3307;
  v2(421,3)=exp(y(38))*exp(y(39));
  v2(422,1)=52;
  v2(422,2)=4960;
  v2(422,3)=(-exp(y(58)));
  v2(423,1)=53;
  v2(423,2)=3394;
  v2(423,3)=(params(18)+y(67))*exp(y(40));
  v2(424,1)=53;
  v2(424,2)=4786;
  v2(424,3)=(-exp(y(56)));
  v2(425,1)=53;
  v2(425,2)=5716;
  v2(425,3)=exp(y(40));
  v2(426,1)=53;
  v2(426,2)=3421;
  v2(426,3)=  v2(425,3);
  v2(427,1)=54;
  v2(427,2)=3481;
  v2(427,3)=(T818*(-(exp(y(41))*exp(y(58))))-(-(exp(y(41))*exp(y(58))))*(T818+T818))/(T818*T818);
  v2(428,1)=54;
  v2(428,2)=4943;
  v2(428,3)=(-(exp(y(41))*exp(y(58))))/T818;
  v2(429,1)=54;
  v2(429,2)=3498;
  v2(429,3)=  v2(428,3);
  v2(430,1)=54;
  v2(430,2)=4960;
  v2(430,3)=T586;
  v2(431,1)=54;
  v2(431,2)=5047;
  v2(431,3)=(-exp(y(59)));
  v2(432,1)=55;
  v2(432,2)=3481;
  v2(432,3)=(T818*(-(exp(y(41))*exp(y(55))))-(-(exp(y(41))*exp(y(55))))*(T818+T818))/(T818*T818);
  v2(433,1)=55;
  v2(433,2)=4685;
  v2(433,3)=(-(exp(y(41))*exp(y(55))))/T818;
  v2(434,1)=55;
  v2(434,2)=3495;
  v2(434,3)=  v2(433,3);
  v2(435,1)=55;
  v2(435,2)=4699;
  v2(435,3)=T592;
  v2(436,1)=55;
  v2(436,2)=5134;
  v2(436,3)=(-exp(y(60)));
  v2(437,1)=56;
  v2(437,2)=1393;
  v2(437,3)=T598;
  v2(438,1)=56;
  v2(438,2)=3457;
  v2(438,3)=(-(exp(y(41))*exp(y(17))))/T818;
  v2(439,1)=56;
  v2(439,2)=1417;
  v2(439,3)=  v2(438,3);
  v2(440,1)=56;
  v2(440,2)=3481;
  v2(440,3)=(T818*(-(exp(y(41))*exp(y(17))))-(-(exp(y(41))*exp(y(17))))*(T818+T818))/(T818*T818);
  v2(441,1)=56;
  v2(441,2)=5221;
  v2(441,3)=(-exp(y(61)));
  v2(442,1)=57;
  v2(442,2)=1219;
  v2(442,3)=T604;
  v2(443,1)=57;
  v2(443,2)=3455;
  v2(443,3)=(-(exp(y(15))*exp(y(41))))/T818;
  v2(444,1)=57;
  v2(444,2)=1245;
  v2(444,3)=  v2(443,3);
  v2(445,1)=57;
  v2(445,2)=3481;
  v2(445,3)=(T818*(-(exp(y(15))*exp(y(41))))-(-(exp(y(15))*exp(y(41))))*(T818+T818))/(T818*T818);
  v2(446,1)=57;
  v2(446,2)=5395;
  v2(446,3)=(-exp(y(63)));
  v2(447,1)=58;
  v2(447,2)=958;
  v2(447,3)=T610;
  v2(448,1)=58;
  v2(448,2)=3452;
  v2(448,3)=(-(exp(y(12))*exp(y(41))))/T818;
  v2(449,1)=58;
  v2(449,2)=987;
  v2(449,3)=  v2(448,3);
  v2(450,1)=58;
  v2(450,2)=3481;
  v2(450,3)=(T818*(-(exp(y(12))*exp(y(41))))-(-(exp(y(12))*exp(y(41))))*(T818+T818))/(T818*T818);
  v2(451,1)=58;
  v2(451,2)=5482;
  v2(451,3)=(-exp(y(64)));
  v2(452,1)=59;
  v2(452,2)=3481;
  v2(452,3)=(T818*(-(exp(y(41))*exp(y(56))))-(-(exp(y(41))*exp(y(56))))*(T818+T818))/(T818*T818);
  v2(453,1)=59;
  v2(453,2)=4771;
  v2(453,3)=(-(exp(y(41))*exp(y(56))))/T818;
  v2(454,1)=59;
  v2(454,2)=3496;
  v2(454,3)=  v2(453,3);
  v2(455,1)=59;
  v2(455,2)=4786;
  v2(455,3)=T616;
  v2(456,1)=59;
  v2(456,2)=5308;
  v2(456,3)=(-exp(y(62)));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),59,7396);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],59,636056);
end
end
