%% THIS FILE COMPUTES SECOND MOMENTS


load options;load steadyInitial;load steady;

load calibration; % added

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 1. SET OPTIONS
numbersimul      = 500;                                          % number of simulation
lengthsimul      = 400;                                          % length of each simulation
drop             = 200;                                          % burn in


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2. RETRIEVE INFRO FROM DYNARE 
order            = options_.order;     
endosize         = length(oo_.dr.ghx);                           % number of endogenous variables
statesize        = M_.npred ;                                    % number of state variables
exosize          = M_.exo_nbr;                                   % number of shocks  
names            = M_.endo_names(oo_.dr.order_var,:);            % list variables in DR order (needed in DR order since output from policy functions will be in DR order)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3 CREATE EMPTY MATRICES TO STORE SIMULATIONS
states           = zeros(statesize,lengthsimul);                 % store state variables   
initval          = zeros(statesize,1);                           % store initial values (in deviation from non-stochastic SS) for state variables
yydev            = zeros(endosize,lengthsimul);                  % store endogenous variables in deviation from non-stochastic steady state
simulstore       = zeros(numbersimul*endosize,lengthsimul);      % store simulations      
stdyy            = zeros(endosize,numbersimul);                  % store standard deviations for each simulation
corrxy           = zeros(endosize,numbersimul);                  % store correlations with GDP for each simulation
autocorrx        = zeros(endosize,numbersimul);                  % store autocorrelations for each simulation
beveridge        = zeros(1,numbersimul);                         % store correlation between vacancies and unemployment for each simulation
corrJFRJSR       = zeros(1,numbersimul);                         % store correlation between job-finding and separation rate for each simulation



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 4. SIMULATE PRUNED POLICY FUNCTIONS AND HP FILTER

for s_index = 1:numbersimul
% std_exo                 = [stdzP 0.027 0.037 0.037];
std_exo                 = sqrt(stdzP^2 + stdgP^2 + stdwP^2 + stdkP^2); 
% E                       = stdzP*randn(1,lengthsimul);    
E                       = std_exo*randn(1,lengthsimul);  
options_.periods        = lengthsimul;    


oo_.dr.npred            = M_.nspred;
oo_.dr.nstatic          = M_.nstatic;
select_state            = M_.nstatic+1 : M_.nstatic + M_.npred + M_.nboth;


simulation_first        = zeros(M_.endo_nbr,options_.periods);
simulation_second       = zeros(M_.endo_nbr,options_.periods);
simulation_first(:,1)   = oo_.dr.ghu*E(:,1);
exe                     = kron(E(:,1),E(:,1));
simulation_second(:,1)  = (1/2)*(oo_.dr.ghuu*exe+oo_.dr.ghs2);


for t=2:options_.periods
        simulation_first(:,t)  = oo_.dr.ghx*simulation_first(select_state,t-1)+oo_.dr.ghu*E(:,t);
         exe  = kron(E(:,t),E(:,t));sxe=kron(simulation_first(select_state,t-1),E(:,t));sxs=kron(simulation_first(select_state,t-1),simulation_first(select_state,t-1));
        simulation_second(:,t) = oo_.dr.ghx*simulation_second(select_state,t-1)...
                                 +(1/2)*(oo_.dr.ghxx*sxs+2*oo_.dr.ghxu*sxe+oo_.dr.ghuu*exe+oo_.dr.ghs2);



% technology shock
% simulation_first(:,1)   = oo_.dr.ghu(:,1)*E(1,1);
% exe                     = kron(E(1,1),E(1,1));
% simulation_second(:,1)  = (1/2)*(oo_.dr.ghuu(:,1)*exe+oo_.dr.ghs2);
% for t=2:options_.periods
% simulation_first(:,t)  = oo_.dr.ghx*simulation_first(select_state,t-1)+oo_.dr.ghu(:,1)*E(1,t);
% exe  = kron(E(1,t),E(1,t));sxe=kron(simulation_first(select_state,t-1),E(1,t));sxs=kron(simulation_first(select_state,t-1),simulation_first(select_state,t-1));
% simulation_second(:,t) = oo_.dr.ghx*simulation_second(select_state,t-1)...
%                                  +(1/2)*(oo_.dr.ghxx*sxs...
%                                  +2*oo_.dr.ghxu(:,1:11)*sxe...
%                                  +oo_.dr.ghuu(:,1)*exe...
%                                  +oo_.dr.ghs2);
                             
 

end
simulations.first   = simulation_first(oo_.dr.inv_order_var,:);
simulations.second  = simulation_second(oo_.dr.inv_order_var,:);
simulations.total   = simulations.second+simulations.first+repmat(oo_.dr.ys,[1 options_.periods]);
yy                  = simulations.total(oo_.dr.order_var,:);




logyy             = yy;
logyy(:,1:drop)   = [];
hplogY            = zeros(endosize,lengthsimul-drop);
trendY            = hplogY;

    for j=1:endosize

    [hplogY(j,:),trendY(j,:)]  = hpfast(logyy(j,:),1600);
    
    end
    

    gdp          = hplogY(strmatch('gdpIncomedata', names, 'exact'),:); %#ok<*MATCH3>
    u            = hplogY(strmatch('u', names, 'exact'),:);
    v            = hplogY(strmatch('v', names, 'exact'),:);
    s            = hplogY(strmatch('s', names, 'exact'),:);
    seprate      = hplogY(strmatch('seprate', names, 'exact'),:);
    
    hplogYt            = hplogY';
    
    stdyy(:,s_index)   = std(hplogYt);
    
    for v_index = 1:endosize
    corrxy(v_index,s_index)      = corr(gdp',hplogY(v_index,:)');  
    autocorrx_loop               = autocorr(hplogY(v_index,:),1);
    autocorrx(v_index,s_index)   = autocorrx_loop(1,2);
    end
    
    beveridge(1, s_index)        = corr(u',v');
    corrJFRJSR(1, s_index)       = corr(s',seprate');
    
    simulstore(1 + (s_index - 1)*endosize: endosize + (s_index - 1)*endosize,:)= yy;
end       

 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 5. AVERAGE OUT HP-FILTERED MOMENTS
if numbersimul>1
stdyy      = mean(stdyy'); %#ok<*UDIM>
corrxy     = mean(corrxy'); 
autocorrx  = mean(autocorrx');
beveridge  = mean(beveridge');
corrJFRJSR = mean(corrJFRJSR');
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 6. PLOT FINAL RESULTS
sigmaYincome       = stdyy(strmatch('gdpIncomedata', names, 'exact'));
sigmaC             = stdyy(strmatch('cmdata', names, 'exact'));
sigmaIK            = stdyy(strmatch('ikdata', names, 'exact'));
sigmaU             = stdyy(strmatch('u', names, 'exact')); 
sigmaV             = stdyy(strmatch('v', names, 'exact'));
sigmaW             = stdyy(strmatch('wdata', names, 'exact'));
sigmaJFR           = stdyy(strmatch('s', names, 'exact'));
sigmaJSR           = stdyy(strmatch('seprate', names, 'exact'));


autocorrYincome    = autocorrx(strmatch('gdpIncomedata', names, 'exact'));
autocorrC          = autocorrx(strmatch('cmdata', names, 'exact'));
autocorrIK         = autocorrx(strmatch('ikdata', names, 'exact'));
autocorrU          = autocorrx(strmatch('u', names, 'exact'));
autocorrJF         = autocorrx(strmatch('s', names, 'exact'));
autocorrJS         = autocorrx(strmatch('seprate', names, 'exact'));
autocorrV          = autocorrx(strmatch('v', names, 'exact'));
autocorrW          = autocorrx(strmatch('wdata', names, 'exact'));


corrCYincome       = corrxy(strmatch('cmdata', names, 'exact'));
corrIKYincome      = corrxy(strmatch('ikdata', names, 'exact'));
corrUYincome       = corrxy(strmatch('u', names, 'exact'));
corrVYincome       = corrxy(strmatch('v', names, 'exact'));
corrWYincome       = corrxy(strmatch('wdata', names, 'exact'));
corrYfYincome      = corrxy(strmatch('yfirm', names, 'exact'));
corrJFRYincome     = corrxy(strmatch('s', names, 'exact'));
corrJSRYincome     = corrxy(strmatch('seprate', names, 'exact'));



display('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
display('ABSOLUTE STANDARD DEVIATIONS')
disp([' sigmaYincome        = ' num2str(sigmaYincome,'%.6f') ]);
disp([' sigmaC              = ' num2str(sigmaC,'%.6f') ]);
disp([' sigmaIK             = ' num2str(sigmaIK,'%.6f') ]);
disp([' sigmaU              = ' num2str(sigmaU,'%.6f') ]);
disp([' sigmaV              = ' num2str(sigmaV,'%.6f') ]);
disp([' sigmaJF             = ' num2str(sigmaJFR,'%.6f') ]);
disp([' sigmaJS             = ' num2str(sigmaJSR,'%.6f') ]);
disp([' sigmaW              = ' num2str(sigmaW,'%.6f') ]);

display('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
display('AUTOCORRELATIONS')
disp([' autocorrYIncome      = ' num2str(autocorrYincome,'%.6f') ]);
disp([' autocorrC            = ' num2str(autocorrC,'%.6f') ]);
disp([' autocorrU            = ' num2str(autocorrU,'%.6f') ]);
disp([' autocorrIK           = ' num2str(autocorrIK,'%.6f') ]);
disp([' autocorrV            = ' num2str(autocorrV,'%.6f') ]);
disp([' autocorrJF           = ' num2str(autocorrJF,'%.6f') ]);
disp([' autocorrJS           = ' num2str(autocorrJS,'%.6f') ]);
disp([' autocorrW            = ' num2str(autocorrW,'%.6f') ]);

display('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
display('CROSS-CORRELATIONS ---- OUTPUT')
disp([' corrCYincome         = ' num2str(corrCYincome,'%.6f') ]);
disp([' corrIYincome         = ' num2str(corrIKYincome,'%.6f') ]);
disp([' corrUYincome         = ' num2str(corrUYincome,'%.6f') ]);
disp([' corrVYincome         = ' num2str(corrVYincome,'%.6f') ]);
disp([' corrJFRYincome       = ' num2str(corrJFRYincome,'%.6f') ]);
disp([' corrJSRYincome       = ' num2str(corrJSRYincome,'%.6f') ]);
disp([' corrWYincome         = ' num2str(corrWYincome,'%.6f') ]);
disp([' corrYfYincome         = ' num2str(corrYfYincome,'%.6f') ]);

display('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
display('BEVERIDGE CURVE')
disp([' beveridge           = ' num2str(beveridge,'%.6f') ]);
